@@ -1,5 +1,6 @@
 """An automl algorithm that consists of two modes: fast and long, where fast is a subset of long."""
 import inspect
+import logging
 
 import numpy as np
 from skopt.space import Categorical, Integer, Real
@@ -18,11 +19,10 @@ from evalml.pipelines.components.utils import (
     get_estimators,
     handle_component_class,
 )
-from evalml.pipelines.utils import (
-    _make_stacked_ensemble_pipeline,
-    make_pipeline,
-)
+from evalml.pipelines.utils import make_pipeline
 from evalml.problem_types import is_regression
+from evalml.utils import infer_feature_types
+from evalml.utils.logger import get_logger
 
 
 class DefaultAlgorithm(AutoMLAlgorithm):
@@ -60,7 +60,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         pipeline_params (dict or None): Pipeline-level parameters that should be passed to the proposed pipelines. Defaults to None.
         custom_hyperparameters (dict or None): Custom hyperparameter ranges specified for pipelines to iterate over. Defaults to None.
         n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines. Defaults to -1.
-        text_in_ensembling (boolean): If True and ensembling is True, then n_jobs will be set to 1 to avoid downstream sklearn stacking issues related to nltk. Defaults to None.
+        text_in_ensembling (boolean): If True and ensembling is True, then n_jobs will be set to 1 to avoid downstream sklearn stacking issues related to nltk. Defaults to False.
         top_n (int): top n number of pipelines to use for long mode.
         num_long_explore_pipelines (int): number of pipelines to explore for each top n pipeline at the start of long mode.
         num_long_pipelines_per_batch (int): number of pipelines per batch for each top n pipeline through long mode.
@@ -77,21 +77,21 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         pipeline_params=None,
         custom_hyperparameters=None,
         n_jobs=-1,
-        text_in_ensembling=None,
+        text_in_ensembling=False,
         top_n=3,
         num_long_explore_pipelines=50,
         num_long_pipelines_per_batch=10,
+        verbose=False,
     ):
         super().__init__(
             allowed_pipelines=[],
             custom_hyperparameters=custom_hyperparameters,
-            max_iterations=None,
             tuner_class=None,
             random_seed=random_seed,
         )
 
-        self.X = X
-        self.y = y
+        self.X = infer_feature_types(X)
+        self.y = infer_feature_types(y)
         self.problem_type = problem_type
         self.sampler_name = sampler_name
 
@@ -100,11 +100,17 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         self.text_in_ensembling = text_in_ensembling
         self._pipeline_params = pipeline_params or {}
         self._custom_hyperparameters = custom_hyperparameters or {}
-        self._selected_cols = None
         self._top_n_pipelines = None
         self.num_long_explore_pipelines = num_long_explore_pipelines
         self.num_long_pipelines_per_batch = num_long_pipelines_per_batch
         self.top_n = top_n
+        self.verbose = verbose
+        if verbose:
+            self.logger = get_logger(f"{__name__}.verbose")
+        else:
+            self.logger = logging.getLogger(__name__)
+
+        self._set_additional_pipeline_params()
         if custom_hyperparameters and not isinstance(custom_hyperparameters, dict):
             raise ValueError(
                 f"If custom_hyperparameters provided, must be of type dict. Received {type(custom_hyperparameters)}"
@@ -221,31 +227,6 @@ class DefaultAlgorithm(AutoMLAlgorithm):
             self._create_tuner(pipeline)
         return pipelines
 
-    def _create_ensemble(self):
-        input_pipelines = []
-        for pipeline_dict in self._best_pipeline_info.values():
-            pipeline = pipeline_dict["pipeline"]
-            pipeline_params = pipeline_dict["parameters"]
-            parameters = self._transform_parameters(pipeline, pipeline_params)
-            if (
-                "Select Columns Transformer"
-                in pipeline.component_graph.component_instances
-            ):
-                parameters.update(
-                    {"Select Columns Transformer": {"columns": self._selected_cols}}
-                )
-            input_pipelines.append(
-                pipeline.new(parameters=parameters, random_seed=self.random_seed)
-            )
-        n_jobs_ensemble = 1 if self.text_in_ensembling else self.n_jobs
-        ensemble = _make_stacked_ensemble_pipeline(
-            input_pipelines,
-            self.problem_type,
-            random_seed=self.random_seed,
-            n_jobs=n_jobs_ensemble,
-        )
-        return [ensemble]
-
     def _create_n_pipelines(self, pipelines, n):
         next_batch = []
         for _ in range(n):
