@@ -1,3 +1,5 @@
+"""Data check that checks if there are any highly-null columns and rows in the input."""
+
 from evalml.data_checks import (
     DataCheck,
     DataCheckAction,
@@ -9,14 +11,13 @@ from evalml.utils import infer_feature_types
 
 
 class HighlyNullDataCheck(DataCheck):
-    """Checks if there are any highly-null columns and rows in the input.
+    """Check if there are any highly-null columns and rows in the input.
 
-    Arguments:
+    Args:
         pct_null_col_threshold(float): If the percentage of NaN values in an input feature exceeds this amount,
             that column will be considered highly-null. Defaults to 0.95.
         pct_null_row_threshold(float): If the percentage of NaN values in an input row exceeds this amount,
             that row will be considered highly-null. Defaults to 0.95.
-
     """
 
     def __init__(self, pct_null_col_threshold=0.95, pct_null_row_threshold=0.95):
@@ -33,11 +34,11 @@ class HighlyNullDataCheck(DataCheck):
         self.pct_null_row_threshold = pct_null_row_threshold
 
     def validate(self, X, y=None):
-        """Checks if there are any highly-null columns or rows in the input.
+        """Check if there are any highly-null columns or rows in the input.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, np.ndarray): Features.
-            y (pd.Series, np.ndarray): Ignored.
+            y (pd.Series, np.ndarray): Ignored. Defaults to None.
 
         Returns:
             dict: dict with a DataCheckWarning if there are any highly-null columns or rows.
@@ -65,15 +66,14 @@ class HighlyNullDataCheck(DataCheck):
             ...                   "data_check_name": "HighlyNullDataCheck",
             ...                   "level": "warning",
             ...                   "code": "HIGHLY_NULL_ROWS",
-            ...                   "details": {"pct_null_cols": highly_null_rows}},
-            ...                  {"message": "Column 'lots_of_null' is 50.0% or more null",
+            ...                   "details": {"pct_null_cols": highly_null_rows, "columns": None, "rows": [0, 1, 2, 3]}},
+            ...                  {"message": "Columns 'lots_of_null' are 50.0% or more null",
             ...                   "data_check_name": "HighlyNullDataCheck",
             ...                   "level": "warning",
             ...                   "code": "HIGHLY_NULL_COLS",
-            ...                   "details": {"column": "lots_of_null", "pct_null_rows": 0.8}}],
-            ...    "actions": [{"code": "DROP_ROWS", "metadata": {"rows": [0, 1, 2, 3]}},
-            ...                {"code": "DROP_COL", "metadata": {"column": "lots_of_null"}}]}
-
+            ...                   "details": {"columns": ["lots_of_null"], "pct_null_rows": {"lots_of_null": 0.8}, "null_row_indices": {"lots_of_null": [0, 1, 2, 3]}, "rows": None}}],
+            ...    "actions": [{"code": "DROP_ROWS", "metadata": {"rows": [0, 1, 2, 3], "columns": None}},
+            ...                {"code": "DROP_COL", "metadata": {"columns": ["lots_of_null"], "rows": None}}]}
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
@@ -90,7 +90,10 @@ class HighlyNullDataCheck(DataCheck):
                     message=warning_msg,
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.HIGHLY_NULL_ROWS,
-                    details={"pct_null_cols": highly_null_rows},
+                    details={
+                        "rows": highly_null_rows.index.tolist(),
+                        "pct_null_cols": highly_null_rows,
+                    },
                 ).to_dict()
             )
             results["actions"].append(
@@ -106,29 +109,32 @@ class HighlyNullDataCheck(DataCheck):
             for key, value in percent_null_cols.items()
             if value >= self.pct_null_col_threshold and value != 0
         }
-        warning_msg = "Column '{}' is {}% or more null"
-        results["warnings"].extend(
-            [
+        highly_null_cols_indices = {
+            col_: X[col_][X[col_].isnull()].index.tolist() for col_ in highly_null_cols
+        }
+        warning_msg = "Columns {} are {}% or more null"
+        if highly_null_cols:
+            results["warnings"].append(
                 DataCheckWarning(
                     message=warning_msg.format(
-                        col_name, self.pct_null_col_threshold * 100
+                        (", ").join(
+                            ["'{}'".format(str(col)) for col in highly_null_cols]
+                        ),
+                        self.pct_null_col_threshold * 100,
                     ),
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.HIGHLY_NULL_COLS,
                     details={
-                        "column": col_name,
-                        "pct_null_rows": highly_null_cols[col_name],
+                        "columns": list(highly_null_cols),
+                        "pct_null_rows": highly_null_cols,
+                        "null_row_indices": highly_null_cols_indices,
                     },
                 ).to_dict()
-                for col_name in highly_null_cols
-            ]
-        )
-        results["actions"].extend(
-            [
+            )
+            results["actions"].append(
                 DataCheckAction(
-                    DataCheckActionCode.DROP_COL, metadata={"column": col_name}
+                    DataCheckActionCode.DROP_COL,
+                    metadata={"columns": list(highly_null_cols)},
                 ).to_dict()
-                for col_name in highly_null_cols
-            ]
-        )
+            )
         return results
