@@ -47,13 +47,13 @@ class IDColumnsDataCheck(DataCheck):
             >>> id_col_check = IDColumnsDataCheck()
             >>> assert id_col_check.validate(df) == {
             ...     "errors": [],
-            ...     "warnings": [{"message": "Column 'df_id' is 100.0% or more likely to be an ID column",
+            ...     "warnings": [{"message": "Columns 'df_id' are 100.0% or more likely to be an ID column",
             ...                   "data_check_name": "IDColumnsDataCheck",
             ...                   "level": "warning",
             ...                   "code": "HAS_ID_COLUMN",
-            ...                   "details": {"column": "df_id"}}],
+            ...                   "details": {"columns": ["df_id"], "rows": None}}],
             ...     "actions": [{"code": "DROP_COL",
-            ...                  "metadata": {"column": "df_id"}}]}
+            ...                  "metadata": {"columns": ["df_id"], "rows": None}}]}
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
@@ -91,24 +91,25 @@ class IDColumnsDataCheck(DataCheck):
         id_cols_above_threshold = {
             key: value for key, value in id_cols.items() if value >= self.id_threshold
         }
-        warning_msg = "Column '{}' is {}% or more likely to be an ID column"
-        results["warnings"].extend(
-            [
+        if id_cols_above_threshold:
+            warning_msg = "Columns {} are {}% or more likely to be an ID column"
+            results["warnings"].append(
                 DataCheckWarning(
-                    message=warning_msg.format(col_name, self.id_threshold * 100),
+                    message=warning_msg.format(
+                        (", ").join(
+                            ["'{}'".format(str(col)) for col in id_cols_above_threshold]
+                        ),
+                        self.id_threshold * 100,
+                    ),
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.HAS_ID_COLUMN,
-                    details={"column": col_name},
+                    details={"columns": list(id_cols_above_threshold)},
                 ).to_dict()
-                for col_name in id_cols_above_threshold
-            ]
-        )
-        results["actions"].extend(
-            [
+            )
+            results["actions"].append(
                 DataCheckAction(
-                    DataCheckActionCode.DROP_COL, metadata={"column": col_name}
+                    DataCheckActionCode.DROP_COL,
+                    metadata={"columns": list(id_cols_above_threshold)},
                 ).to_dict()
-                for col_name in id_cols_above_threshold
-            ]
-        )
+            )
         return results
