@@ -1,6 +1,7 @@
+"""Data check that checks if the target data contains certain distributions that may need to be transformed prior training to improve model performance."""
 import numpy as np
 import woodwork as ww
-from scipy.stats import shapiro
+from scipy.stats import jarque_bera, shapiro
 
 from evalml.data_checks import (
     DataCheck,
@@ -14,13 +15,12 @@ from evalml.utils import infer_feature_types
 
 
 class TargetDistributionDataCheck(DataCheck):
-    """Checks if the target data contains certain distributions that may need to be transformed prior training to
-    improve model performance."""
+    """Check if the target data contains certain distributions that may need to be transformed prior training to improve model performance. Uses the Shapiro-Wilks test when the dataset is <=5000 samples, otherwise uses Jarque-Bera."""
 
     def validate(self, X, y):
-        """Checks if the target data has a certain distribution.
+        """Check if the target data has a certain distribution.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, np.ndarray): Features. Ignored.
             y (pd.Series, np.ndarray): Target data to check for underlying distributions.
 
@@ -29,17 +29,16 @@ class TargetDistributionDataCheck(DataCheck):
 
         Example:
             >>> from scipy.stats import lognorm
-            >>> X = None
             >>> y = [0.946, 0.972, 1.154, 0.954, 0.969, 1.222, 1.038, 0.999, 0.973, 0.897]
             >>> target_check = TargetDistributionDataCheck()
-            >>> assert target_check.validate(X, y) == {
+            >>> assert target_check.validate(None, y) == {
             ...     "errors": [],
             ...     "warnings": [{"message": "Target may have a lognormal distribution.",
             ...                   "data_check_name": "TargetDistributionDataCheck",
             ...                   "level": "warning",
             ...                   "code": "TARGET_LOGNORMAL_DISTRIBUTION",
-            ...                   "details": {"shapiro-statistic/pvalue": '0.84/0.045'}}],
-            ...     "actions": [{'code': 'TRANSFORM_TARGET', 'metadata': {'column': None, 'transformation_strategy': 'lognormal', 'is_target': True}}]}
+            ...                   "details": {"shapiro-statistic/pvalue": '0.8/0.045', "columns": None, "rows": None}}],
+            ...     "actions": [{'code': 'TRANSFORM_TARGET', 'metadata': {'transformation_strategy': 'lognormal', 'is_target': True, "columns": None, "rows": None}}]}
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
@@ -75,8 +74,10 @@ class TargetDistributionDataCheck(DataCheck):
             )
             return results
 
+        normalization_test = shapiro if len(y) <= 5000 else jarque_bera
+        normalization_test_string = "shapiro" if len(y) <= 5000 else "jarque_bera"
         # Check if a normal distribution is detected with p-value above 0.05
-        if shapiro(y).pvalue >= 0.05:
+        if normalization_test(y).pvalue >= 0.05:
             return results
 
         y_new = round(y, 6)
@@ -86,19 +87,19 @@ class TargetDistributionDataCheck(DataCheck):
         y_new = y_new[
             y_new < (y_new.mean() + 3 * round(y.std(), 3))
         ]  # Drop values greater than 3 standard deviations
-        shapiro_test_og = shapiro(y_new)
-        shapiro_test_log = shapiro(np.log(y_new))
+        norm_test_og = normalization_test(y_new)
+        norm_test_log = normalization_test(np.log(y_new))
 
         log_detected = False
 
         # If the p-value of the log transformed target is greater than or equal to the p-value of the original target
         # with outliers dropped, then it would imply that the log transformed target has more of a normal distribution
-        if shapiro_test_log.pvalue >= shapiro_test_og.pvalue:
+        if norm_test_log.pvalue >= norm_test_og.pvalue:
             log_detected = True
 
         if log_detected:
             details = {
-                "shapiro-statistic/pvalue": f"{round(shapiro_test_og.statistic, 1)}/{round(shapiro_test_og.pvalue, 3)}"
+                f"{normalization_test_string}-statistic/pvalue": f"{round(norm_test_og.statistic, 1)}/{round(norm_test_og.pvalue, 3)}"
             }
             results["warnings"].append(
                 DataCheckWarning(
@@ -112,7 +113,6 @@ class TargetDistributionDataCheck(DataCheck):
                 DataCheckAction(
                     DataCheckActionCode.TRANSFORM_TARGET,
                     metadata={
-                        "column": None,
                         "is_target": True,
                         "transformation_strategy": "lognormal",
                     },
