@@ -1,3 +1,5 @@
+"""Data check that checks if any of the features are highly correlated with the target by using mutual information or Pearson correlation."""
+
 from evalml.data_checks import (
     DataCheck,
     DataCheckAction,
@@ -12,14 +14,13 @@ from evalml.utils.woodwork_utils import (
 
 
 class TargetLeakageDataCheck(DataCheck):
-    """
-    Check if any of the features are highly correlated with the target by using mutual information or Pearson correlation.
+    """Check if any of the features are highly correlated with the target by using mutual information or Pearson correlation.
 
     If `method='mutual'`, this data check uses mutual information and supports all target and feature types.
     Otherwise, if `method='pearson'`, it uses Pearson correlation and only supports binary with numeric and boolean dtypes.
     Pearson correlation returns a value in [-1, 1], while mutual information returns a value in [0, 1].
 
-    Arguments:
+    Args:
         pct_corr_threshold (float): The correlation threshold to be considered leakage. Defaults to 0.95.
         method (string): The method to determine correlation. Use 'mutual' for mutual information, otherwise 'pearson' for Pearson correlation. Defaults to 'mutual'.
     """
@@ -68,9 +69,9 @@ class TargetLeakageDataCheck(DataCheck):
         If `method='mutual'`, supports all target and feature types. Otherwise, if `method='pearson'` only supports binary with numeric and boolean dtypes.
         Pearson correlation returns a value in [-1, 1], while mutual information returns a value in [0, 1].
 
-        Arguments:
-            X (pd.DataFrame, np.ndarray): The input features to check
-            y (pd.Series, np.ndarray): The target data
+        Args:
+            X (pd.DataFrame, np.ndarray): The input features to check.
+            y (pd.Series, np.ndarray): The target data.
 
         Returns:
             dict (DataCheckWarning): dict with a DataCheckWarning if target leakage is detected.
@@ -89,10 +90,10 @@ class TargetLeakageDataCheck(DataCheck):
             ...                   "data_check_name": "TargetLeakageDataCheck",
             ...                   "level": "warning",
             ...                   "code": "TARGET_LEAKAGE",
-            ...                   "details": {"column": "leak"}}],
+            ...                   "details": {"columns": ["leak"], "rows": None}}],
             ...     "errors": [],
             ...     "actions": [{"code": "DROP_COL",
-            ...                  "metadata": {"column": "leak"}}]}
+            ...                  "metadata": {"columns": ["leak"], "rows": None}}]}
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
@@ -104,24 +105,31 @@ class TargetLeakageDataCheck(DataCheck):
         else:
             highly_corr_cols = self._calculate_mutual_information(X, y)
 
-        warning_msg = "Column '{}' is {}% or more correlated with the target"
-        results["warnings"].extend(
-            [
+        warning_msg_singular = "Column {} is {}% or more correlated with the target"
+        warning_msg_plural = "Columns {} are {}% or more correlated with the target"
+
+        if highly_corr_cols:
+            if len(highly_corr_cols) == 1:
+                warning_msg = warning_msg_singular.format(
+                    "'{}'".format(str(highly_corr_cols[0])),
+                    self.pct_corr_threshold * 100,
+                )
+            else:
+                warning_msg = warning_msg_plural.format(
+                    (", ").join(["'{}'".format(str(col)) for col in highly_corr_cols]),
+                    self.pct_corr_threshold * 100,
+                )
+            results["warnings"].append(
                 DataCheckWarning(
-                    message=warning_msg.format(col_name, self.pct_corr_threshold * 100),
+                    message=warning_msg,
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-                    details={"column": col_name},
+                    details={"columns": highly_corr_cols},
                 ).to_dict()
-                for col_name in highly_corr_cols
-            ]
-        )
-        results["actions"].extend(
-            [
+            )
+            results["actions"].append(
                 DataCheckAction(
-                    DataCheckActionCode.DROP_COL, metadata={"column": col_name}
+                    DataCheckActionCode.DROP_COL, metadata={"columns": highly_corr_cols}
                 ).to_dict()
-                for col_name in highly_corr_cols
-            ]
-        )
+            )
         return results
