@@ -13,7 +13,12 @@ from evalml.model_family import ModelFamily
 from evalml.model_understanding.prediction_explanations._report_creator_factory import (
     _report_creator_factory,
 )
-from evalml.problem_types import ProblemTypes, is_regression, is_time_series
+from evalml.problem_types import (
+    ProblemTypes,
+    is_classification,
+    is_regression,
+    is_time_series,
+)
 from evalml.utils import infer_feature_types
 from evalml.utils.gen_utils import drop_rows_with_nans
 
@@ -40,32 +45,36 @@ def explain_predictions(
     y,
     indices_to_explain,
     top_k_features=3,
-    include_shap_values=False,
+    include_explainer_values=False,
     include_expected_value=False,
     output_format="text",
     training_data=None,
     training_target=None,
+    algorithm="shap",
 ):
     """Creates a report summarizing the top contributing features for each data point in the input features.
 
-    XGBoost and Stacked Ensemble models, as well as CatBoost multiclass classifiers, are not currently supported.
+    XGBoost models and CatBoost multiclass classifiers are not currently supported with the SHAP algorithm.
+    To explain XGBoost model predictions, use the LIME algorithm. The LIME algorithm does not currently support
+    any CatBoost models. Stacked Ensemble models are not supported by either algorithm at this time.
 
     Args:
-        pipeline (PipelineBase): Fitted pipeline whose predictions we want to explain with SHAP.
+        pipeline (PipelineBase): Fitted pipeline whose predictions we want to explain with SHAP or LIME.
         input_features (pd.DataFrame): Dataframe of input data to evaluate the pipeline on.
         y (pd.Series): Labels for the input data.
         indices_to_explain (list[int]): List of integer indices to explain.
         top_k_features (int): How many of the highest/lowest contributing feature to include in the table for each
             data point.  Default is 3.
-        include_shap_values (bool): Whether SHAP values should be included in the table. Default is False.
+        include_explainer_values (bool): Whether explainer (SHAP or LIME) values should be included in the table. Default is False.
         include_expected_value (bool): Whether the expected value should be included in the table. Default is False.
         output_format (str): Either "text", "dict", or "dataframe". Default is "text".
         training_data (pd.DataFrame, np.ndarray): Data the pipeline was trained on. Required and only used for time series pipelines.
         training_target (pd.Series, np.ndarray): Targets used to train the pipeline. Required and only used for time series pipelines.
+        algorithm (str): Algorithm to use while generating top contributing features, one of "shap" or "lime". Defaults to "shap".
 
     Returns:
         str, dict, or pd.DataFrame: A report explaining the top contributing features to each prediction for each row of input_features.
-            The report will include the feature names, prediction contribution, and SHAP Value (optional).
+            The report will include the feature names, prediction contribution, and explainer value (optional).
 
     Raises:
         ValueError: if input_features is empty.
@@ -93,8 +102,14 @@ def explain_predictions(
             "Prediction explanations for time series pipelines requires that training_target and "
             "training_data are not None"
         )
+    if algorithm not in ["shap", "lime"]:
+        raise ValueError(
+            f"Unknown algorithm {algorithm}, should be one of ['shap', 'lime']"
+        )
+    if algorithm == "lime" and "CatBoost" in pipeline.estimator.name:
+        raise ValueError("CatBoost models are not supported by LIME at this time")
 
-    pipeline_features = pipeline.compute_estimator_features(
+    pipeline_features = pipeline.transform_all_but_final(
         input_features, y, training_data, training_target
     )
 
@@ -115,8 +130,9 @@ def explain_predictions(
         report_type="explain_predictions",
         output_format=output_format,
         top_k_features=top_k_features,
-        include_shap_values=include_shap_values,
+        include_explainer_values=include_explainer_values,
         include_expected_value=include_expected_value,
+        algorithm=algorithm,
     )
     return report_creator(data)
 
@@ -139,7 +155,7 @@ class ExplainPredictionsStage(Enum):
     PREPROCESSING_STAGE = "preprocessing_stage"
     PREDICT_STAGE = "predict_stage"
     COMPUTE_FEATURE_STAGE = "compute_feature_stage"
-    COMPUTE_SHAP_VALUES_STAGE = "compute_shap_value_stage"
+    COMPUTE_EXPLAINER_VALUES_STAGE = "compute_explainer_value_stage"
     DONE = "done"
 
 
@@ -149,25 +165,28 @@ def explain_predictions_best_worst(
     y_true,
     num_to_explain=5,
     top_k_features=3,
-    include_shap_values=False,
+    include_explainer_values=False,
     metric=None,
     output_format="text",
     callback=None,
     training_data=None,
     training_target=None,
+    algorithm="shap",
 ):
     """Creates a report summarizing the top contributing features for the best and worst points in the dataset as measured by error to true labels.
 
-    XGBoost and Stacked Ensemble models, as well as CatBoost multiclass classifiers, are not currently supported.
+    XGBoost models and CatBoost multiclass classifiers are not currently supported with the SHAP algorithm.
+    To explain XGBoost model predictions, use the LIME algorithm. The LIME algorithm does not currently support
+    any CatBoost models. Stacked Ensemble models are not supported by either algorithm at this time.
 
     Args:
-        pipeline (PipelineBase): Fitted pipeline whose predictions we want to explain with SHAP.
+        pipeline (PipelineBase): Fitted pipeline whose predictions we want to explain with SHAP or LIME.
         input_features (pd.DataFrame): Input data to evaluate the pipeline on.
         y_true (pd.Series): True labels for the input data.
         num_to_explain (int): How many of the best, worst, random data points to explain.
         top_k_features (int): How many of the highest/lowest contributing feature to include in the table for each
             data point.
-        include_shap_values (bool): Whether SHAP values should be included in the table. Default is False.
+        include_explainer_values (bool): Whether explainer (SHAP or LIME) values should be included in the table. Default is False.
         metric (callable): The metric used to identify the best and worst points in the dataset. Function must accept
             the true labels and predicted value or probabilities as the only arguments and lower values
             must be better. By default, this will be the absolute error for regression problems and cross entropy loss
@@ -178,11 +197,12 @@ def explain_predictions_best_worst(
             - time_elapsed: total time in seconds that has elapsed since start of call
         training_data (pd.DataFrame, np.ndarray): Data the pipeline was trained on. Required and only used for time series pipelines.
         training_target (pd.Series, np.ndarray): Targets used to train the pipeline. Required and only used for time series pipelines.
+        algorithm (str): Algorithm to use while generating top contributing features, one of "shap" or "lime". Defaults to "shap".
 
     Returns:
         str, dict, or pd.DataFrame: A report explaining the top contributing features for the best/worst predictions in the input_features.
             For each of the best/worst rows of input_features, the predicted values, true labels, metric value,
-            feature names, prediction contribution, and SHAP Value (optional) will be listed.
+            feature names, prediction contribution, and explainer value (optional) will be listed.
 
     Raises:
         ValueError: If input_features does not have more than twice the requested features to explain.
@@ -227,6 +247,12 @@ def explain_predictions_best_worst(
             "Prediction explanations for time series pipelines requires that training_target and "
             "training_data are not None"
         )
+    if algorithm not in ["shap", "lime"]:
+        raise ValueError(
+            f"Unknown algorithm {algorithm}, should be one of ['shap', 'lime']"
+        )
+    if algorithm == "lime" and "CatBoost" in pipeline.estimator.name:
+        raise ValueError("CatBoost models are not supported by LIME at this time")
 
     try:
         if is_regression(pipeline.problem_type):
@@ -253,7 +279,9 @@ def explain_predictions_best_worst(
             y_true_no_nan, y_pred_no_nan, y_pred_values_no_nan = drop_rows_with_nans(
                 y_true, y_pred, y_pred_values
             )
-            errors = metric(pipeline._encode_targets(y_true_no_nan), y_pred_no_nan)
+            if is_classification(pipeline.problem_type):
+                y_true_no_nan = pipeline._encode_targets(y_true_no_nan)
+            errors = metric(y_true_no_nan, y_pred_no_nan)
     except Exception as e:
         tb = traceback.format_tb(sys.exc_info()[2])
         raise PipelineScoreError(
@@ -269,12 +297,15 @@ def explain_predictions_best_worst(
         start_time, timer(), ExplainPredictionsStage.COMPUTE_FEATURE_STAGE, callback
     )
 
-    pipeline_features = pipeline.compute_estimator_features(
+    pipeline_features = pipeline.transform_all_but_final(
         input_features, y_true, training_data, training_target
     )
 
     _update_progress(
-        start_time, timer(), ExplainPredictionsStage.COMPUTE_SHAP_VALUES_STAGE, callback
+        start_time,
+        timer(),
+        ExplainPredictionsStage.COMPUTE_EXPLAINER_VALUES_STAGE,
+        callback,
     )
 
     data = _ReportData(
@@ -294,9 +325,10 @@ def explain_predictions_best_worst(
         report_type="explain_predictions_best_worst",
         output_format=output_format,
         top_k_features=top_k_features,
-        include_shap_values=include_shap_values,
+        include_explainer_values=include_explainer_values,
         num_to_explain=num_to_explain,
         include_expected_value=True,
+        algorithm=algorithm,
     )
 
     _update_progress(start_time, timer(), ExplainPredictionsStage.DONE, callback)
