@@ -1,6 +1,7 @@
 """Base machine learning pipeline class."""
 import copy
 import inspect
+import json
 import logging
 import os
 import sys
@@ -16,8 +17,6 @@ from .components import (
     DFSTransformer,
     Estimator,
     LinearDiscriminantAnalysis,
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
 )
 from .components.utils import all_components, handle_component_class
 
@@ -255,7 +254,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             pipeline_dict.update({"components": component_dict})
             return pipeline_dict
 
-    def compute_estimator_features(self, X, y=None, X_train=None, y_train=None):
+    def transform_all_but_final(self, X, y=None, X_train=None, y_train=None):
         """Transforms the data by applying all pre-processing components.
 
         Args:
@@ -267,7 +266,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             pd.DataFrame: New transformed features.
         """
-        return self.component_graph.compute_final_component_features(X, y=y)
+        return self.component_graph.transform_all_but_final(X, y=y)
 
     def _fit(self, X, y):
         self.input_target_name = y.name
@@ -426,6 +425,50 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         df = pd.DataFrame(importance, columns=["feature", "importance"])
         return df
 
+    def graph_json(self):
+        """Generates a JSON with nodes consisting of the component names and parameters, and edges detailing component relationships.
+
+        x_edges specifies from which component feature data is being passed.
+        y_edges specifies from which component target data is being passed.
+        This can be used to build graphs across a variety of visualization tools.
+        Template:
+        {"Nodes": {"component_name": {"Name": class_name, "Attributes": parameters_attributes}, ...}},
+        "x_edges": [[from_component_name, to_component_name], [from_component_name, to_component_name], ...],
+        "y_edges": [[from_component_name, to_component_name], [from_component_name, to_component_name], ...]}
+
+        Returns:
+            dag_json (str): A serialized JSON representation of a DAG structure.
+        """
+        nodes = {
+            comp_: {"Attributes": att_.parameters, "Name": att_.name}
+            for comp_, att_ in self.component_graph.component_instances.items()
+        }
+
+        x_edges = self.component_graph._get_edges(
+            self.component_graph.component_dict, "features"
+        )
+        y_edges = self.component_graph._get_edges(
+            self.component_graph.component_dict, "target"
+        )
+        for (
+            component_name,
+            component_info,
+        ) in self.component_graph.component_dict.items():
+            for parent in component_info[1:]:
+                if parent == "X":
+                    x_edges.append(("X", component_name))
+                elif parent == "y":
+                    y_edges.append(("y", component_name))
+        nodes.update({"X": "X", "y": "y"})
+        graph_as_json = {"Nodes": nodes, "x_edges": x_edges, "y_edges": y_edges}
+
+        for x_edge in graph_as_json["x_edges"]:
+            if x_edge[0] == "X":
+                graph_as_json["x_edges"].remove(x_edge)
+                graph_as_json["x_edges"].insert(0, x_edge)
+
+        return json.dumps(graph_as_json, indent=4)
+
     def graph(self, filepath=None):
         """Generate an image representing the pipeline graph.
 
@@ -559,17 +602,20 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             return cloudpickle.load(f)
 
     def clone(self):
-        """Constructs a new pipeline with the same components, parameters, and random state.
+        """Constructs a new pipeline with the same components, parameters, and random seed.
 
         Returns:
-            A new instance of this pipeline with identical components, parameters, and random state.
+            A new instance of this pipeline with identical components, parameters, and random seed.
         """
-        return self.__class__(
+        clone = self.__class__(
             self.component_graph,
             parameters=self.parameters,
             custom_name=self.custom_name,
             random_seed=self.random_seed,
         )
+        if is_binary(self.problem_type):
+            clone.threshold = self.threshold
+        return clone
 
     def new(self, parameters, random_seed=0):
         """Constructs a new instance of the pipeline with the same component graph but with a different set of parameters. Not to be confused with python's __new__ method.
@@ -672,19 +718,12 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             for c in self.component_graph
         )
         has_dfs = any(isinstance(c, DFSTransformer) for c in self.component_graph)
-        has_stacked_ensembler = any(
-            isinstance(
-                c, (SklearnStackedEnsembleClassifier, SklearnStackedEnsembleRegressor)
-            )
-            for c in self.component_graph
-        )
         return not any(
             [
                 has_more_than_one_estimator,
                 has_custom_components,
                 has_dim_reduction,
                 has_dfs,
-                has_stacked_ensembler,
             ]
         )
 
