@@ -1,6 +1,7 @@
 from unittest.mock import patch
 
 import numpy as np
+import pandas as pd
 import pytest
 from skopt.space import Categorical, Integer
 
@@ -11,8 +12,8 @@ from evalml.pipelines.components import (
     ElasticNetRegressor,
     LogisticRegressionClassifier,
     RandomForestClassifier,
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor,
 )
 from evalml.problem_types import ProblemTypes
 
@@ -22,13 +23,14 @@ def test_default_algorithm_init(X_y_binary):
     problem_type = "binary"
     sampler_name = "Undersampler"
 
-    algo = DefaultAlgorithm(X, y, problem_type, sampler_name)
+    algo = DefaultAlgorithm(X, y, problem_type, sampler_name, verbose=True)
 
     assert algo.problem_type == problem_type
     assert algo.sampler_name == sampler_name
     assert algo.pipeline_number == 0
     assert algo.batch_number == 0
     assert algo.allowed_pipelines == []
+    assert algo.verbose is True
 
 
 def test_default_algorithm_custom_hyperparameters_error(X_y_binary):
@@ -138,7 +140,7 @@ def test_default_algorithm(
     final_ensemble = algo.next_batch()
     assert isinstance(
         final_ensemble[0].estimator,
-        (SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier),
+        (StackedEnsembleClassifier, StackedEnsembleRegressor),
     )
     add_result(algo, final_ensemble)
 
@@ -150,7 +152,7 @@ def test_default_algorithm(
     long_first_ensemble = algo.next_batch()
     assert isinstance(
         long_first_ensemble[0].estimator,
-        (SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier),
+        (StackedEnsembleClassifier, StackedEnsembleRegressor),
     )
 
     long = algo.next_batch()
@@ -161,7 +163,7 @@ def test_default_algorithm(
     long_second_ensemble = algo.next_batch()
     assert isinstance(
         long_second_ensemble[0].estimator,
-        (SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier),
+        (StackedEnsembleClassifier, StackedEnsembleRegressor),
     )
 
     long_2 = algo.next_batch()
@@ -195,7 +197,7 @@ def test_evalml_algo_pipeline_params(mock_get_names, X_y_binary):
         batch = algo.next_batch()
         add_result(algo, batch)
         for pipeline in batch:
-            if not isinstance(pipeline.estimator, SklearnStackedEnsembleClassifier):
+            if not isinstance(pipeline.estimator, StackedEnsembleClassifier):
                 assert pipeline.parameters["pipeline"] == {"gap": 2, "max_delay": 10}
             if isinstance(pipeline.estimator, LogisticRegressionClassifier):
                 assert pipeline.parameters["Logistic Regression Classifier"]["C"] == 5
@@ -235,3 +237,30 @@ def test_evalml_algo_custom_hyperparameters(mock_get_names, X_y_binary):
                 assert pipeline.parameters["Random Forest Classifier"][
                     "max_depth"
                 ] in Categorical([5, 6, 7])
+
+
+@patch("evalml.pipelines.components.FeatureSelector.get_names")
+@pytest.mark.parametrize("columns", [["unknown_col"], ["unknown1, unknown2"]])
+def test_default_algo_drop_columns(mock_get_names, columns, X_y_binary):
+    X, y = X_y_binary
+    mock_get_names.return_value = ["0", "1", "2"]
+
+    X = pd.DataFrame(X)
+    for col in columns:
+        X[col] = pd.Series(range(len(X)))
+    X.ww.init()
+    X.ww.set_types({col: "Unknown" for col in columns})
+
+    algo = DefaultAlgorithm(X, y, "binary", sampler_name=None)
+
+    assert algo._pipeline_params["Drop Columns Transformer"]["columns"] == columns
+
+    for _ in range(4):
+        batch = algo.next_batch()
+        add_result(algo, batch)
+        for pipeline in batch:
+            if not isinstance(pipeline.estimator, StackedEnsembleClassifier):
+                assert (
+                    pipeline.parameters["Drop Columns Transformer"]["columns"]
+                    == columns
+                )
