@@ -11,56 +11,15 @@ from evalml.automl.automl_algorithm import (
 from evalml.model_family import ModelFamily
 from evalml.pipelines import (
     BinaryClassificationPipeline,
-    RegressionPipeline,
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
+    Estimator,
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor,
 )
-from evalml.pipelines.components import Estimator
 from evalml.pipelines.components.utils import get_estimators
 from evalml.pipelines.utils import make_pipeline
 from evalml.problem_types import ProblemTypes
 
 
-def test_iterative_algorithm_init_iterative():
-    IterativeAlgorithm()
-
-
-def test_iterative_algorithm_init():
-    algo = IterativeAlgorithm()
-    assert algo.pipeline_number == 0
-    assert algo.batch_number == 0
-    assert algo.allowed_pipelines == []
-
-
-def test_make_iterative_algorithm_custom_hyperparameters_error(
-    dummy_binary_pipeline_classes,
-):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes()
-
-    custom_hyperparameters = [
-        {"Imputer": {"numeric_imput_strategy": ["median"]}},
-        {"One Hot Encoder": {"value1": ["value2"]}},
-    ]
-
-    with pytest.raises(
-        ValueError, match="If custom_hyperparameters provided, must be of type dict"
-    ):
-        IterativeAlgorithm(
-            allowed_pipelines=dummy_binary_pipeline_classes,
-            custom_hyperparameters=custom_hyperparameters,
-        )
-
-
-def test_iterative_algorithm_allowed_pipelines(
-    logistic_regression_binary_pipeline_class,
-):
-    allowed_pipelines = [logistic_regression_binary_pipeline_class({})]
-    algo = IterativeAlgorithm(allowed_pipelines=allowed_pipelines)
-    assert algo.pipeline_number == 0
-    assert algo.batch_number == 0
-    assert algo.allowed_pipelines == allowed_pipelines
-
-
 @pytest.fixture
 def dummy_binary_pipeline_classes():
     def _method(hyperparameters=["default", "other"]):
@@ -86,17 +45,107 @@ def dummy_binary_pipeline_classes():
                     random_seed=random_seed,
                 )
 
+        allowed_component_graphs = {
+            "graph_1": [MockEstimator],
+            "graph_2": [MockEstimator],
+            "graph_3": [MockEstimator],
+        }
         return [
             BinaryClassificationPipeline([MockEstimator]),
             BinaryClassificationPipeline([MockEstimator]),
             BinaryClassificationPipeline([MockEstimator]),
-        ]
+        ], allowed_component_graphs
 
     return _method
 
 
-def test_iterative_algorithm_empty(dummy_binary_pipeline_classes):
-    algo = IterativeAlgorithm()
+def test_iterative_algorithm_init(
+    X_y_binary,
+):
+    X, y = X_y_binary
+
+    algo = IterativeAlgorithm(X=X, y=y, problem_type="binary")
+    assert algo.pipeline_number == 0
+    assert algo.batch_number == 0
+
+    estimators = get_estimators("binary")
+    assert len(algo.allowed_pipelines) == len(
+        [
+            make_pipeline(
+                X,
+                y,
+                estimator,
+                "binary",
+            )
+            for estimator in estimators
+        ]
+    )
+
+
+def test_make_iterative_algorithm_custom_hyperparameters_error(
+    dummy_binary_pipeline_classes, X_y_binary
+):
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+    X, y = X_y_binary
+
+    custom_hyperparameters = [
+        {"Imputer": {"numeric_imput_strategy": ["median"]}},
+        {"One Hot Encoder": {"value1": ["value2"]}},
+    ]
+
+    with pytest.raises(
+        ValueError, match="If custom_hyperparameters provided, must be of type dict"
+    ):
+        IterativeAlgorithm(
+            X=X,
+            y=y,
+            problem_type="binary",
+            allowed_component_graphs=allowed_component_graphs,
+            custom_hyperparameters=custom_hyperparameters,
+        )
+
+
+def test_iterative_algorithm_allowed_pipelines(
+    X_y_binary, dummy_binary_pipeline_classes
+):
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+    algo = IterativeAlgorithm(
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
+    )
+    assert algo.pipeline_number == 0
+    assert algo.batch_number == 0
+    assert algo.allowed_pipelines == dummy_binary_pipeline_classes
+
+
+def test_iterative_algorithm_empty(X_y_binary, dummy_binary_pipeline_classes):
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+
+    with pytest.raises(ValueError, match="No allowed pipelines to search"):
+        IterativeAlgorithm(X=X, y=y, problem_type="binary", allowed_component_graphs={})
+
+    algo = IterativeAlgorithm(
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
+    )
+    algo.allowed_pipelines = []
     assert algo.pipeline_number == 0
     assert algo.batch_number == 0
     assert algo.allowed_pipelines == []
@@ -115,16 +164,26 @@ def test_iterative_algorithm_empty(dummy_binary_pipeline_classes):
 
 
 @pytest.mark.parametrize("ensembling_value", [True, False])
-@patch(
-    "evalml.pipelines.components.ensemble.SklearnStackedEnsembleClassifier._stacking_estimator_class"
-)
 @patch("evalml.tuners.skopt_tuner.Optimizer.tell")
 def test_iterative_algorithm_results(
-    mock_opt_tell, mock_stack, ensembling_value, dummy_binary_pipeline_classes
+    mock_opt_tell,
+    ensembling_value,
+    dummy_binary_pipeline_classes,
+    X_y_binary,
 ):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes()
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+
     algo = IterativeAlgorithm(
-        allowed_pipelines=dummy_binary_pipeline_classes, ensembling=ensembling_value
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
+        ensembling=ensembling_value,
     )
     assert algo.pipeline_number == 0
     assert algo.batch_number == 0
@@ -195,28 +254,32 @@ def test_iterative_algorithm_results(
                 algo.add_result(score, pipeline, {"id": algo.pipeline_number})
             assert pipeline.model_family == ModelFamily.ENSEMBLE
             assert pipeline.random_seed == algo.random_seed
-            stack_args = mock_stack.call_args[1]["estimators"]
-            estimators_used_in_ensemble = [args[1] for args in stack_args]
+            estimators_used_in_ensemble = pipeline.component_graph.get_estimators()
             random_seeds_the_same = [
-                (estimator.pipeline.random_seed == algo.random_seed)
+                (estimator.random_seed == algo.random_seed)
                 for estimator in estimators_used_in_ensemble
             ]
             assert all(random_seeds_the_same)
             assert ModelFamily.ENSEMBLE not in algo._best_pipeline_info
 
 
-@pytest.mark.parametrize("ensembling_value", [True, False])
-@patch(
-    "evalml.pipelines.components.ensemble.SklearnStackedEnsembleClassifier._stacking_estimator_class"
-)
 @patch("evalml.tuners.skopt_tuner.Optimizer.tell")
 def test_iterative_algorithm_passes_pipeline_params(
-    mock_opt_tell, mock_stack, ensembling_value, dummy_binary_pipeline_classes
+    mock_opt_tell,
+    X_y_binary,
+    dummy_binary_pipeline_classes,
 ):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes()
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
     algo = IterativeAlgorithm(
-        allowed_pipelines=dummy_binary_pipeline_classes,
-        ensembling=ensembling_value,
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
         pipeline_params={
             "pipeline": {"gap": 2, "max_delay": 10, "forecast_horizon": 3}
         },
@@ -250,25 +313,24 @@ def test_iterative_algorithm_passes_pipeline_params(
             for score, pipeline in zip(scores, next_batch):
                 algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
-        if ensembling_value:
-            next_batch = algo.next_batch()
-            input_pipelines = next_batch[0].parameters[
-                "Sklearn Stacked Ensemble Classifier"
-            ]["input_pipelines"]
-            assert all(
-                [
-                    pl.parameters["pipeline"]
-                    == {"gap": 2, "max_delay": 10, "forecast_horizon": 3}
-                    for pl in input_pipelines
-                ]
-            )
-
 
 @patch("evalml.tuners.skopt_tuner.Optimizer.tell")
-def test_iterative_algorithm_passes_njobs(mock_opt_tell, dummy_binary_pipeline_classes):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes()
+def test_iterative_algorithm_passes_njobs(
+    mock_opt_tell, X_y_binary, dummy_binary_pipeline_classes
+):
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
     algo = IterativeAlgorithm(
-        allowed_pipelines=dummy_binary_pipeline_classes, n_jobs=2, ensembling=False
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
+        n_jobs=2,
+        ensembling=False,
     )
     next_batch = algo.next_batch()
 
@@ -292,7 +354,7 @@ def test_iterative_algorithm_passes_njobs(mock_opt_tell, dummy_binary_pipeline_c
 @pytest.mark.parametrize("is_regression", [True, False])
 @pytest.mark.parametrize("estimator", ["XGBoost", "CatBoost"])
 def test_iterative_algorithm_passes_n_jobs_catboost_xgboost(
-    mock_opt_tell, is_regression, estimator
+    mock_opt_tell, X_y_binary, X_y_regression, is_regression, estimator
 ):
     if estimator == "XGBoost":
         pytest.importorskip(
@@ -303,11 +365,22 @@ def test_iterative_algorithm_passes_n_jobs_catboost_xgboost(
             "catboost", reason="Skipping test because catboost is not installed."
         )
     if is_regression:
-        pipelines = [RegressionPipeline([f"{estimator} Regressor"])]
+        X, y = X_y_regression
+        component_graphs = {"graph": [f"{estimator} Regressor"]}
+        problem_type = "regression"
     else:
-        pipelines = [BinaryClassificationPipeline([f"{estimator} Classifier"])]
+        X, y = X_y_binary
+        component_graphs = {"graph": [f"{estimator} Classifier"]}
+        problem_type = "binary"
 
-    algo = IterativeAlgorithm(allowed_pipelines=pipelines, n_jobs=2, ensembling=False)
+    algo = IterativeAlgorithm(
+        X=X,
+        y=y,
+        problem_type=problem_type,
+        allowed_component_graphs=component_graphs,
+        n_jobs=2,
+        ensembling=False,
+    )
     next_batch = algo.next_batch()
 
     # the "best" score will be the 1st dummy pipeline
@@ -316,7 +389,7 @@ def test_iterative_algorithm_passes_n_jobs_catboost_xgboost(
         algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     for _ in range(1, 3):
-        for _ in range(len(pipelines)):
+        for _ in range(len(component_graphs)):
             next_batch = algo.next_batch()
             for parameter_values in [list(p.parameters.values()) for p in next_batch]:
                 assert parameter_values[0]["n_jobs"] == 2
@@ -327,23 +400,34 @@ def test_iterative_algorithm_passes_n_jobs_catboost_xgboost(
 
 @pytest.mark.parametrize("ensembling_value", [True, False])
 def test_iterative_algorithm_one_allowed_pipeline(
-    ensembling_value, logistic_regression_binary_pipeline_class
+    X_y_binary, ensembling_value, dummy_binary_pipeline_classes
 ):
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+    dummy_binary_pipeline_classes = [dummy_binary_pipeline_classes[0]]
+    allowed_component_graphs = {"graph_1": allowed_component_graphs["graph_1"]}
     # Checks that when len(allowed_pipeline) == 1, ensembling is not run, even if set to True
     algo = IterativeAlgorithm(
-        allowed_pipelines=[logistic_regression_binary_pipeline_class({})],
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
         ensembling=ensembling_value,
     )
     assert algo.pipeline_number == 0
     assert algo.batch_number == 0
-    assert algo.allowed_pipelines == [logistic_regression_binary_pipeline_class({})]
+    assert algo.allowed_pipelines == dummy_binary_pipeline_classes
 
     # initial batch contains one of each pipeline, with default parameters
     next_batch = algo.next_batch()
     assert len(next_batch) == 1
     assert [p.__class__ for p in next_batch] == [
-        logistic_regression_binary_pipeline_class
-    ] * len(next_batch)
+        p.__class__ for p in dummy_binary_pipeline_classes
+    ]
     assert algo.pipeline_number == 1
     assert algo.batch_number == 1
     assert all(
@@ -363,8 +447,8 @@ def test_iterative_algorithm_one_allowed_pipeline(
         assert len(next_batch) == algo.pipelines_per_batch
         assert all((p.random_seed == algo.random_seed) for p in next_batch)
         assert [p.__class__ for p in next_batch] == [
-            logistic_regression_binary_pipeline_class
-        ] * len(next_batch)
+            dummy_binary_pipeline_classes[0].__class__
+        ] * algo.pipelines_per_batch
         assert algo.pipeline_number == last_pipeline_number + len(next_batch)
         last_pipeline_number = algo.pipeline_number
         assert algo.batch_number == last_batch_number + 1
@@ -377,9 +461,9 @@ def test_iterative_algorithm_one_allowed_pipeline(
         assert any(
             [
                 p
-                != logistic_regression_binary_pipeline_class(
-                    {}
-                ).component_graph.default_parameters
+                != dummy_binary_pipeline_classes[0]
+                .__class__({})
+                .component_graph.default_parameters
                 for p in all_parameters
             ]
         )
@@ -388,15 +472,28 @@ def test_iterative_algorithm_one_allowed_pipeline(
 @pytest.mark.parametrize("text_in_ensembling", [True, False])
 @pytest.mark.parametrize("n_jobs", [-1, 0, 1, 2, 3])
 def test_iterative_algorithm_stacked_ensemble_n_jobs_binary(
-    n_jobs, text_in_ensembling, dummy_binary_pipeline_classes
+    n_jobs,
+    X_y_binary,
+    text_in_ensembling,
+    dummy_binary_pipeline_classes,
 ):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes()
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+
     algo = IterativeAlgorithm(
-        allowed_pipelines=dummy_binary_pipeline_classes,
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
         ensembling=True,
         text_in_ensembling=text_in_ensembling,
         n_jobs=n_jobs,
     )
+
     next_batch = algo.next_batch()
     seen_ensemble = False
     scores = range(0, len(next_batch))
@@ -406,20 +503,16 @@ def test_iterative_algorithm_stacked_ensemble_n_jobs_binary(
     for i in range(5):
         next_batch = algo.next_batch()
         for pipeline in next_batch:
-            if isinstance(pipeline.estimator, SklearnStackedEnsembleClassifier):
+            if isinstance(pipeline.estimator, StackedEnsembleClassifier):
                 seen_ensemble = True
                 if text_in_ensembling:
                     assert (
-                        pipeline.parameters["Sklearn Stacked Ensemble Classifier"][
-                            "n_jobs"
-                        ]
+                        pipeline.parameters["Stacked Ensemble Classifier"]["n_jobs"]
                         == 1
                     )
                 else:
                     assert (
-                        pipeline.parameters["Sklearn Stacked Ensemble Classifier"][
-                            "n_jobs"
-                        ]
+                        pipeline.parameters["Stacked Ensemble Classifier"]["n_jobs"]
                         == n_jobs
                     )
     assert seen_ensemble
@@ -428,13 +521,19 @@ def test_iterative_algorithm_stacked_ensemble_n_jobs_binary(
 @pytest.mark.parametrize("text_in_ensembling", [True, False])
 @pytest.mark.parametrize("n_jobs", [-1, 0, 1, 2, 3])
 def test_iterative_algorithm_stacked_ensemble_n_jobs_regression(
-    n_jobs, text_in_ensembling, linear_regression_pipeline_class
+    n_jobs, text_in_ensembling, X_y_regression, linear_regression_pipeline_class
 ):
+    X, y = X_y_regression
+
+    allowed_component_graphs = {
+        "graph_1": linear_regression_pipeline_class.component_graph,
+        "graph_2": linear_regression_pipeline_class.component_graph,
+    }
     algo = IterativeAlgorithm(
-        allowed_pipelines=[
-            linear_regression_pipeline_class({}),
-            linear_regression_pipeline_class({}),
-        ],
+        X=X,
+        y=y,
+        problem_type="regression",
+        allowed_component_graphs=allowed_component_graphs,
         ensembling=True,
         text_in_ensembling=text_in_ensembling,
         n_jobs=n_jobs,
@@ -448,20 +547,15 @@ def test_iterative_algorithm_stacked_ensemble_n_jobs_regression(
     for i in range(5):
         next_batch = algo.next_batch()
         for pipeline in next_batch:
-            if isinstance(pipeline.estimator, SklearnStackedEnsembleRegressor):
+            if isinstance(pipeline.estimator, StackedEnsembleRegressor):
                 seen_ensemble = True
                 if text_in_ensembling:
                     assert (
-                        pipeline.parameters["Sklearn Stacked Ensemble Regressor"][
-                            "n_jobs"
-                        ]
-                        == 1
+                        pipeline.parameters["Stacked Ensemble Regressor"]["n_jobs"] == 1
                     )
                 else:
                     assert (
-                        pipeline.parameters["Sklearn Stacked Ensemble Regressor"][
-                            "n_jobs"
-                        ]
+                        pipeline.parameters["Stacked Ensemble Regressor"]["n_jobs"]
                         == n_jobs
                     )
     assert seen_ensemble
@@ -472,10 +566,16 @@ def test_iterative_algorithm_stacked_ensemble_n_jobs_regression(
     [1, "hello", 1.3, -1.0006, Categorical([1, 3, 4]), Integer(2, 4), Real(2, 6)],
 )
 def test_iterative_algorithm_pipeline_params(
+    X_y_binary,
     parameters,
     dummy_binary_pipeline_classes,
 ):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes(parameters)
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes(parameters)
 
     if isinstance(parameters, (Categorical, Integer, Real)):
         with pytest.raises(
@@ -483,7 +583,10 @@ def test_iterative_algorithm_pipeline_params(
             match="Pipeline parameters should not contain skopt.Space variables",
         ):
             IterativeAlgorithm(
-                allowed_pipelines=dummy_binary_pipeline_classes,
+                X=X,
+                y=y,
+                problem_type="binary",
+                allowed_component_graphs=allowed_component_graphs,
                 random_seed=0,
                 pipeline_params={
                     "pipeline": {"gap": 2, "max_delay": 10, "forecast_horizon": 3},
@@ -493,7 +596,10 @@ def test_iterative_algorithm_pipeline_params(
         return
     else:
         algo = IterativeAlgorithm(
-            allowed_pipelines=dummy_binary_pipeline_classes,
+            X=X,
+            y=y,
+            problem_type="binary",
+            allowed_component_graphs=allowed_component_graphs,
             random_seed=0,
             pipeline_params={
                 "pipeline": {"gap": 2, "max_delay": 10, "forecast_horizon": 3},
@@ -543,16 +649,27 @@ def test_iterative_algorithm_pipeline_params(
     ],
 )
 def test_iterative_algorithm_custom_hyperparameters(
-    parameters, hyperparameters, dummy_binary_pipeline_classes
+    parameters,
+    hyperparameters,
+    X_y_binary,
+    dummy_binary_pipeline_classes,
 ):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes(parameters)
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes(parameters)
 
     if not isinstance(hyperparameters, (Categorical, Integer, Real)):
         with pytest.raises(
             ValueError, match="Custom hyperparameters should only contain skopt"
         ):
             IterativeAlgorithm(
-                allowed_pipelines=dummy_binary_pipeline_classes,
+                X=X,
+                y=y,
+                problem_type="binary",
+                allowed_component_graphs=allowed_component_graphs,
                 random_seed=0,
                 pipeline_params={"Mock Classifier": {"dummy_parameter": parameters}},
                 custom_hyperparameters={
@@ -562,7 +679,10 @@ def test_iterative_algorithm_custom_hyperparameters(
         return
     else:
         algo = IterativeAlgorithm(
-            allowed_pipelines=dummy_binary_pipeline_classes,
+            X=X,
+            y=y,
+            problem_type="binary",
+            allowed_component_graphs=allowed_component_graphs,
             random_seed=0,
             pipeline_params={"Mock Classifier": {"dummy_parameter": parameters}},
             custom_hyperparameters={
@@ -608,10 +728,21 @@ def test_iterative_algorithm_custom_hyperparameters(
         assert all_dummies == {1, 3, 4} if parameters == 1 else all_dummies == {2, 3, 4}
 
 
-def test_iterative_algorithm_pipeline_params_kwargs(dummy_binary_pipeline_classes):
-    dummy_binary_pipeline_classes = dummy_binary_pipeline_classes()
+def test_iterative_algorithm_pipeline_params_kwargs(
+    X_y_binary, dummy_binary_pipeline_classes
+):
+    X, y = X_y_binary
+
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+
     algo = IterativeAlgorithm(
-        allowed_pipelines=dummy_binary_pipeline_classes,
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
         pipeline_params={
             "Mock Classifier": {"dummy_parameter": "dummy", "fake_param": "fake"}
         },
@@ -629,13 +760,26 @@ def test_iterative_algorithm_pipeline_params_kwargs(dummy_binary_pipeline_classe
 
 
 def test_iterative_algorithm_results_best_pipeline_info_id(
-    dummy_binary_pipeline_classes, logistic_regression_binary_pipeline_class
+    X_y_binary,
+    dummy_binary_pipeline_classes,
+    logistic_regression_binary_pipeline_class,
 ):
-    allowed_pipelines = [
-        dummy_binary_pipeline_classes()[0],
-        logistic_regression_binary_pipeline_class({}),
-    ]
-    algo = IterativeAlgorithm(allowed_pipelines=allowed_pipelines)
+    X, y = X_y_binary
+    LogisticRegressionBinaryPipeline = logistic_regression_binary_pipeline_class
+    (
+        dummy_binary_pipeline_classes,
+        allowed_component_graphs,
+    ) = dummy_binary_pipeline_classes()
+    allowed_component_graphs = {
+        "graph_1": allowed_component_graphs["graph_1"],
+        "graph_2": LogisticRegressionBinaryPipeline.component_graph,
+    }
+    algo = IterativeAlgorithm(
+        X=X,
+        y=y,
+        problem_type="binary",
+        allowed_component_graphs=allowed_component_graphs,
+    )
 
     # initial batch contains one of each pipeline, with default parameters
     next_batch = algo.next_batch()
@@ -668,71 +812,50 @@ def test_iterative_algorithm_first_batch_order(
     problem_type, X_y_binary, has_minimal_dependencies
 ):
     X, y = X_y_binary
-    estimators = get_estimators(problem_type, None)
-    pipelines = [make_pipeline(X, y, e, problem_type) for e in estimators]
-    algo = IterativeAlgorithm(allowed_pipelines=pipelines)
+
+    algo = IterativeAlgorithm(X=X, y=y, problem_type=problem_type)
 
     # initial batch contains one of each pipeline, with default parameters
     next_batch = algo.next_batch()
     estimators_in_first_batch = [p.estimator.name for p in next_batch]
 
     if problem_type == ProblemTypes.REGRESSION:
-        final_estimators = [
+        linear_models = ["Elastic Net Regressor"]
+        extra_dep_estimators = [
             "XGBoost Regressor",
             "LightGBM Regressor",
             "CatBoost Regressor",
         ]
+        core_estimators = [
+            "Random Forest Regressor",
+            "Decision Tree Regressor",
+            "Extra Trees Regressor",
+        ]
     else:
-        final_estimators = [
+        linear_models = ["Elastic Net Classifier", "Logistic Regression Classifier"]
+        extra_dep_estimators = [
             "XGBoost Classifier",
             "LightGBM Classifier",
             "CatBoost Classifier",
         ]
+        core_estimators = [
+            "Random Forest Classifier",
+            "Decision Tree Classifier",
+            "Extra Trees Classifier",
+        ]
     if has_minimal_dependencies:
-        final_estimators = []
-    if problem_type == ProblemTypes.REGRESSION:
-        assert (
-            estimators_in_first_batch
-            == [
-                "Elastic Net Regressor",
-                "Decision Tree Regressor",
-                "Extra Trees Regressor",
-                "Random Forest Regressor",
-            ]
-            + final_estimators
-        )
-    if problem_type == ProblemTypes.BINARY:
-        assert (
-            estimators_in_first_batch
-            == [
-                "Elastic Net Classifier",
-                "Logistic Regression Classifier",
-                "Decision Tree Classifier",
-                "Extra Trees Classifier",
-                "Random Forest Classifier",
-            ]
-            + final_estimators
-        )
-    if problem_type == ProblemTypes.MULTICLASS:
-        assert (
-            estimators_in_first_batch
-            == [
-                "Elastic Net Classifier",
-                "Logistic Regression Classifier",
-                "Decision Tree Classifier",
-                "Extra Trees Classifier",
-                "Random Forest Classifier",
-            ]
-            + final_estimators
-        )
+        extra_dep_estimators = []
+    assert (
+        estimators_in_first_batch
+        == linear_models + extra_dep_estimators + core_estimators
+    )
 
 
 def test_iterative_algorithm_first_batch_order_param(
     X_y_binary, has_minimal_dependencies
 ):
     X, y = X_y_binary
-    estimators = get_estimators("binary", None)
-    pipelines = [make_pipeline(X, y, e, "binary") for e in estimators]
+
     # put random forest first
     estimator_family_order = [
         ModelFamily.RANDOM_FOREST,
@@ -744,7 +867,7 @@ def test_iterative_algorithm_first_batch_order_param(
         ModelFamily.CATBOOST,
     ]
     algo = IterativeAlgorithm(
-        allowed_pipelines=pipelines, _estimator_family_order=estimator_family_order
+        X=X, y=y, problem_type="binary", _estimator_family_order=estimator_family_order
     )
     next_batch = algo.next_batch()
     estimators_in_first_batch = [p.estimator.name for p in next_batch]
@@ -782,13 +905,12 @@ def test_iterative_algorithm_sampling_params(
             "Minimal dependencies, so we don't test the oversamplers for iterative algorithm"
         )
     X, y = mock_imbalanced_data_X_y(problem_type, "some", "small")
-    estimators = get_estimators(problem_type, None)
-    pipelines = [
-        make_pipeline(X, y, e, problem_type, sampler_name=sampler) for e in estimators
-    ]
     algo = IterativeAlgorithm(
-        allowed_pipelines=pipelines,
+        X=X,
+        y=y,
+        problem_type=problem_type,
         random_seed=0,
+        sampler_name=sampler,
     )
     next_batch = algo.next_batch()
     for p in next_batch:
