@@ -50,8 +50,9 @@ def test_column_transformer_empty_X(class_to_test):
         transformer = class_to_test(column_types=["not in data"])
     else:
         transformer = class_to_test(columns=["not in data"])
-    with pytest.raises(ValueError, match="not found in input data"):
-        transformer.fit(X)
+    if class_to_test is not SelectColumns:
+        with pytest.raises(ValueError, match="not found in input data"):
+            transformer.fit(X)
 
     transformer = class_to_test(columns=list(X.columns))
     assert transformer.transform(X).empty
@@ -187,10 +188,10 @@ def test_column_transformer_fit_transform(class_to_test, checking_functions):
         assert check3(X, class_to_test(columns=list(X.columns)).fit_transform(X))
 
 
-@pytest.mark.parametrize("class_to_test", [DropColumns, SelectColumns])
-def test_drop_column_transformer_input_invalid_col_name(class_to_test):
+def test_drop_column_transformer_input_invalid_col_name():
     X = pd.DataFrame({"one": [1, 2, 3, 4], "two": [2, 3, 4, 5], "three": [1, 2, 3, 4]})
-    transformer = class_to_test(columns=["not in data"])
+    transformer = DropColumns(columns=["not in data"])
+
     with pytest.raises(ValueError, match="not found in input data"):
         transformer.fit(X)
     with pytest.raises(ValueError, match="not found in input data"):
@@ -199,7 +200,7 @@ def test_drop_column_transformer_input_invalid_col_name(class_to_test):
         transformer.fit_transform(X)
 
     X = np.arange(12).reshape(3, 4)
-    transformer = class_to_test(columns=[5])
+    transformer = DropColumns(columns=[5])
     with pytest.raises(ValueError, match="not found in input data"):
         transformer.fit(X)
     with pytest.raises(ValueError, match="not found in input data"):
@@ -282,3 +283,11 @@ def test_typeortag_column_transformer_ww_logical_and_semantic_types():
 
     X_t = SelectByType(column_types=["numeric"]).fit_transform(X)
     assert X_t.astype(str).equals(X[["three", "four"]].astype(str))
+
+
+def test_column_selector_missing_columns():
+    selector = SelectColumns(columns=["A", "B", "C", "D"])
+    X = pd.DataFrame(columns=["A", "C", "F", "G"])
+
+    X_t = selector.fit_transform(X)
+    assert (X_t.columns == ["A", "C"]).all()
