@@ -16,7 +16,7 @@ from evalml.exceptions import (
     MethodPropertyNotFoundError,
 )
 from evalml.model_family import ModelFamily
-from evalml.pipelines import BinaryClassificationPipeline, RegressionPipeline
+from evalml.pipelines import BinaryClassificationPipeline
 from evalml.pipelines.components import (
     LSA,
     PCA,
@@ -66,8 +66,19 @@ from evalml.pipelines.components import (
     XGBoostRegressor,
 )
 from evalml.pipelines.components.ensemble import (
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
+    StackedEnsembleBase,
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor,
+)
+from evalml.pipelines.components.estimators.classifiers.vowpal_wabbit_classifiers import (
+    VowpalWabbitBinaryClassifier,
+    VowpalWabbitMulticlassClassifier,
+)
+from evalml.pipelines.components.estimators.regressors.vowpal_wabbit_regressor import (
+    VowpalWabbitRegressor,
+)
+from evalml.pipelines.components.transformers.encoders.label_encoder import (
+    LabelEncoder,
 )
 from evalml.pipelines.components.transformers.preprocessing.log_transformer import (
     LogTransformer,
@@ -75,9 +86,6 @@ from evalml.pipelines.components.transformers.preprocessing.log_transformer impo
 from evalml.pipelines.components.transformers.samplers.base_sampler import (
     BaseSampler,
 )
-from evalml.pipelines.components.transformers.transformer import (
-    TargetTransformer,
-)
 from evalml.pipelines.components.utils import (
     _all_estimators,
     _all_transformers,
@@ -91,9 +99,9 @@ from evalml.problem_types import ProblemTypes
 def test_classes():
     class MockComponent(ComponentBase):
         name = "Mock Component"
-        model_family = ModelFamily.NONE
         modifies_features = True
         modifies_target = False
+        training_only = False
 
     class MockEstimator(Estimator):
         name = "Mock Estimator"
@@ -103,6 +111,9 @@ def test_classes():
     class MockTransformer(Transformer):
         name = "Mock Transformer"
 
+        def transform(self, X, y=None):
+            return X
+
     return MockComponent, MockEstimator, MockTransformer
 
 
@@ -121,10 +132,10 @@ def test_estimator_needs_fitting_false():
 
 
 class MockFitComponent(ComponentBase):
-    model_family = ModelFamily.NONE
     name = "Mock Fit Component"
     modifies_features = True
     modifies_target = False
+    training_only = False
 
     def __init__(self, param_a=2, param_b=10, random_seed=0):
         parameters = {"param_a": param_a, "param_b": param_b}
@@ -507,11 +518,61 @@ def test_describe_component():
         }
     except ImportError:
         pass
+    try:
+        vw_binary_classifier = VowpalWabbitBinaryClassifier(
+            loss_function="classic",
+            learning_rate=0.1,
+            decay_learning_rate=1.0,
+            power_t=0.1,
+            passes=1,
+        )
+        vw_multi_classifier = VowpalWabbitMulticlassClassifier(
+            loss_function="classic",
+            learning_rate=0.1,
+            decay_learning_rate=1.0,
+            power_t=0.1,
+            passes=1,
+        )
+        vw_regressor = VowpalWabbitRegressor(
+            learning_rate=0.1, decay_learning_rate=1.0, power_t=0.1, passes=1
+        )
+
+        assert vw_binary_classifier.describe(return_dict=True) == {
+            "name": "Vowpal Wabbit Binary Classifier",
+            "parameters": {
+                "loss_function": "classic",
+                "learning_rate": 0.1,
+                "decay_learning_rate": 1.0,
+                "power_t": 0.1,
+                "passes": 1,
+            },
+        }
+        assert vw_multi_classifier.describe(return_dict=True) == {
+            "name": "Vowpal Wabbit Multiclass Classifier",
+            "parameters": {
+                "loss_function": "classic",
+                "learning_rate": 0.1,
+                "decay_learning_rate": 1.0,
+                "power_t": 0.1,
+                "passes": 1,
+            },
+        }
+        assert vw_regressor.describe(return_dict=True) == {
+            "name": "Vowpal Wabbit Regressor",
+            "parameters": {
+                "learning_rate": 0.1,
+                "decay_learning_rate": 1.0,
+                "power_t": 0.1,
+                "passes": 1,
+            },
+        }
+    except ImportError:
+        pass
 
 
 def test_missing_attributes(X_y_binary):
     class MockComponentName(ComponentBase):
-        model_family = ModelFamily.NONE
+        pass
 
     with pytest.raises(TypeError):
         MockComponentName()
@@ -534,12 +595,6 @@ def test_missing_methods_on_components(X_y_binary, test_classes):
     X, y = X_y_binary
     MockComponent, MockEstimator, MockTransformer = test_classes
 
-    class MockTransformerWithFit(Transformer):
-        name = "Mock Transformer"
-
-        def fit(self, X, y=None):
-            return self
-
     component = MockComponent()
     with pytest.raises(
         MethodPropertyNotFoundError,
@@ -566,28 +621,18 @@ def test_missing_methods_on_components(X_y_binary, test_classes):
         estimator.feature_importance
 
     transformer = MockTransformer()
-    transformer_with_fit = MockTransformerWithFit()
     transformer._is_fitted = True
     with pytest.raises(
         MethodPropertyNotFoundError,
         match="Component requires a fit method or a component_obj that implements fit",
     ):
         transformer.fit(X, y)
-    with pytest.raises(
-        MethodPropertyNotFoundError,
-        match="Transformer requires a transform method or a component_obj that implements transform",
-    ):
         transformer.transform(X)
     with pytest.raises(
         MethodPropertyNotFoundError,
         match="Component requires a fit method or a component_obj that implements fit",
     ):
         transformer.fit_transform(X)
-    with pytest.raises(
-        MethodPropertyNotFoundError,
-        match="Transformer requires a transform method or a component_obj that implements transform",
-    ):
-        transformer_with_fit.fit_transform(X)
 
 
 def test_component_fit(X_y_binary):
@@ -622,6 +667,9 @@ def test_component_fit_transform(X_y_binary):
         def fit_transform(self, X, y=None):
             return X
 
+        def transform(self, X, y=None):
+            return X
+
         def __init__(self):
             parameters = {}
             super().__init__(parameters=parameters, component_obj=None, random_seed=0)
@@ -633,6 +681,9 @@ def test_component_fit_transform(X_y_binary):
         def fit_transform(self, X, y=None):
             raise RuntimeError
 
+        def transform(self, X, y=None):
+            return X
+
         def __init__(self):
             parameters = {}
             super().__init__(parameters=parameters, component_obj=None, random_seed=0)
@@ -651,17 +702,6 @@ def test_component_fit_transform(X_y_binary):
             parameters = {}
             super().__init__(parameters=parameters, component_obj=None, random_seed=0)
 
-    class MockTransformerWithOnlyFit(Transformer):
-        name = "Mock Transformer"
-        hyperparameter_ranges = {}
-
-        def fit(self, X, y=None):
-            return self
-
-        def __init__(self):
-            parameters = {}
-            super().__init__(parameters=parameters, component_obj=None, random_seed=0)
-
     # convert data to pd DataFrame, because the component classes don't
     # standardize to pd DataFrame
     X = pd.DataFrame(X)
@@ -677,16 +717,10 @@ def test_component_fit_transform(X_y_binary):
     component = MockTransformerWithFitAndTransform()
     assert isinstance(component.fit_transform(X, y), pd.DataFrame)
 
-    component = MockTransformerWithOnlyFit()
-    with pytest.raises(MethodPropertyNotFoundError):
-        component.fit_transform(X, y)
-
 
 def test_model_family_components(test_classes):
-    MockComponent, MockEstimator, MockTransformer = test_classes
+    _, MockEstimator, _ = test_classes
 
-    assert MockComponent.model_family == ModelFamily.NONE
-    assert MockTransformer.model_family == ModelFamily.NONE
     assert MockEstimator.model_family == ModelFamily.LINEAR_MODEL
 
 
@@ -720,19 +754,7 @@ def test_component_parameters_init(
 ):
     for component_class in all_components():
         print("Testing component {}".format(component_class.name))
-        try:
-            component = component_class()
-        except EnsembleMissingPipelinesError:
-            if component_class == SklearnStackedEnsembleClassifier:
-                component = component_class(
-                    input_pipelines=[
-                        logistic_regression_binary_pipeline_class(parameters={})
-                    ]
-                )
-            elif component_class == SklearnStackedEnsembleRegressor:
-                component = component_class(
-                    input_pipelines=[linear_regression_pipeline_class(parameters={})]
-                )
+        component = component_class()
         parameters = component.parameters
 
         component2 = component_class(**parameters)
@@ -776,11 +798,16 @@ def test_components_init_kwargs():
             continue
         if component._component_obj is None:
             continue
+        if isinstance(component, StackedEnsembleBase):
+            continue
 
         obj_class = component._component_obj.__class__.__name__
         module = component._component_obj.__module__
         importlib.import_module(module, obj_class)
         patched = module + "." + obj_class + ".__init__"
+        if component_class == LabelEncoder:
+            # scikit-learn's LabelEncoder found in different module than where we import from
+            patched = module[: module.rindex(".")] + "." + obj_class + ".__init__"
 
         def all_init(self, *args, **kwargs):
             for k, v in kwargs.items():
@@ -790,7 +817,7 @@ def test_components_init_kwargs():
             component = component_class(test_arg="test")
             component_with_different_kwargs = component_class(diff_test_arg="test")
             assert component.parameters["test_arg"] == "test"
-            if not isinstance(component, PolynomialDetrender):
+            if not isinstance(component, (PolynomialDetrender, LabelEncoder)):
                 assert component._component_obj.test_arg == "test"
             # Test equality of different components with same or different kwargs
             assert component == component_class(test_arg="test")
@@ -823,7 +850,7 @@ def test_transformer_transform_output_type(X_y_binary):
     ]
 
     for component_class in _all_transformers():
-        if component_class in [PolynomialDetrender, LogTransformer]:
+        if component_class in [PolynomialDetrender, LogTransformer, LabelEncoder]:
             # Skipping because these tests are handled in their respective test files
             continue
         print("Testing transformer {}".format(component_class.name))
@@ -913,7 +940,10 @@ def test_transformer_transform_output_type(X_y_binary):
         cls
         for cls in all_components()
         if cls
-        not in [SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier]
+        not in [
+            StackedEnsembleClassifier,
+            StackedEnsembleRegressor,
+        ]
     ],
 )
 def test_default_parameters(cls):
@@ -922,15 +952,7 @@ def test_default_parameters(cls):
     ), f"{cls.__name__}'s default parameters don't match __init__."
 
 
-@pytest.mark.parametrize(
-    "cls",
-    [
-        cls
-        for cls in all_components()
-        if cls
-        not in [SklearnStackedEnsembleRegressor, SklearnStackedEnsembleClassifier]
-    ],
-)
+@pytest.mark.parametrize("cls", [cls for cls in all_components()])
 def test_default_parameters_raise_no_warnings(cls):
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter("always")
@@ -1004,6 +1026,9 @@ def test_transformer_check_for_fit(X_y_binary):
                 random_seed=random_seed,
             )
 
+        def transform(self, X, y=None):
+            return X
+
         def inverse_transform(self, X, y=None):
             return X, y
 
@@ -1028,7 +1053,7 @@ def test_transformer_check_for_fit_with_overrides(X_y_binary):
         def fit(self, X, y):
             return self
 
-        def transform(self, X):
+        def transform(self, X, y=None):
             df = pd.DataFrame()
             df.ww.init()
             return df
@@ -1039,7 +1064,7 @@ def test_transformer_check_for_fit_with_overrides(X_y_binary):
         def fit(self, X, y):
             return self
 
-        def transform(self, X):
+        def transform(self, X, y=None):
             df = pd.DataFrame()
             df.ww.init()
             return df
@@ -1106,9 +1131,12 @@ def test_all_estimators_check_fit(
         for estimator in _all_estimators()
         if estimator
         not in [
-            SklearnStackedEnsembleClassifier,
-            SklearnStackedEnsembleRegressor,
+            StackedEnsembleClassifier,
+            StackedEnsembleRegressor,
             TimeSeriesBaselineEstimator,
+            VowpalWabbitBinaryClassifier,
+            VowpalWabbitMulticlassClassifier,
+            VowpalWabbitRegressor,
         ]
     ] + [test_estimator_needs_fitting_false]
     for component_class in estimators_to_check:
@@ -1191,29 +1219,7 @@ def test_serialization(X_y_binary, ts_data, tmpdir, helper_functions):
     path = os.path.join(str(tmpdir), "component.pkl")
     for component_class in all_components():
         print("Testing serialization of component {}".format(component_class.name))
-        try:
-            component = helper_functions.safe_init_component_with_njobs_1(
-                component_class
-            )
-        except EnsembleMissingPipelinesError:
-            if component_class == SklearnStackedEnsembleClassifier:
-                component = component_class(
-                    input_pipelines=[
-                        BinaryClassificationPipeline(
-                            [RandomForestClassifier],
-                            parameters={"Random Forest Classifier": {"n_jobs": 1}},
-                        )
-                    ]
-                )
-            elif component_class == SklearnStackedEnsembleRegressor:
-                component = component_class(
-                    input_pipelines=[
-                        RegressionPipeline(
-                            [RandomForestRegressor],
-                            parameters={"Random Forest Regressor": {"n_jobs": 1}},
-                        )
-                    ]
-                )
+        component = helper_functions.safe_init_component_with_njobs_1(component_class)
         if (
             isinstance(component, Estimator)
             and ProblemTypes.TIME_SERIES_REGRESSION in component.supported_problem_types
@@ -1232,8 +1238,16 @@ def test_serialization(X_y_binary, ts_data, tmpdir, helper_functions):
                 return_dict=True
             )
             if issubclass(component_class, Estimator) and not (
-                isinstance(component, SklearnStackedEnsembleClassifier)
-                or isinstance(component, SklearnStackedEnsembleRegressor)
+                isinstance(
+                    component,
+                    (
+                        StackedEnsembleClassifier,
+                        StackedEnsembleRegressor,
+                        VowpalWabbitBinaryClassifier,
+                        VowpalWabbitMulticlassClassifier,
+                        VowpalWabbitRegressor,
+                    ),
+                )
             ):
                 assert (
                     component.feature_importance == loaded_component.feature_importance
@@ -1265,19 +1279,7 @@ def test_estimators_accept_all_kwargs(
     logistic_regression_binary_pipeline_class,
     linear_regression_pipeline_class,
 ):
-    try:
-        estimator = estimator_class()
-    except EnsembleMissingPipelinesError:
-        if estimator_class == SklearnStackedEnsembleClassifier:
-            estimator = estimator_class(
-                input_pipelines=[
-                    logistic_regression_binary_pipeline_class(parameters={})
-                ]
-            )
-        elif estimator_class == SklearnStackedEnsembleRegressor:
-            estimator = estimator_class(
-                input_pipelines=[linear_regression_pipeline_class(parameters={})]
-            )
+    estimator = estimator_class()
     if estimator._component_obj is None:
         pytest.skip(
             f"Skipping {estimator_class} because does not have component object."
@@ -1300,12 +1302,14 @@ def test_component_equality_different_classes():
         model_family = ModelFamily.NONE
         modifies_features = True
         modifies_target = False
+        training_only = False
 
     class MockComponentWithADifferentName(ComponentBase):
         name = "Mock Component"
         model_family = ModelFamily.NONE
         modifies_features = True
         modifies_target = False
+        training_only = False
 
     assert MockComponent() != MockComponentWithADifferentName()
 
@@ -1316,6 +1320,7 @@ def test_component_equality_subclasses():
         model_family = ModelFamily.NONE
         modifies_features = True
         modifies_target = False
+        training_only = False
 
     class MockEstimatorSubclass(MockComponent):
         pass
@@ -1329,6 +1334,7 @@ def test_component_equality():
         model_family = ModelFamily.NONE
         modifies_features = True
         modifies_target = False
+        training_only = False
 
         def __init__(self, param_1=0, param_2=0, random_seed=0, **kwargs):
             parameters = {"param_1": param_1, "param_2": param_2}
@@ -1367,16 +1373,7 @@ def test_component_equality_all_components(
     logistic_regression_binary_pipeline_class,
     linear_regression_pipeline_class,
 ):
-    if component_class == SklearnStackedEnsembleClassifier:
-        component = component_class(
-            input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})]
-        )
-    elif component_class == SklearnStackedEnsembleRegressor:
-        component = component_class(
-            input_pipelines=[linear_regression_pipeline_class(parameters={})]
-        )
-    else:
-        component = component_class()
+    component = component_class()
     parameters = component.parameters
     equal_component = component_class(**parameters)
     assert component == equal_component
@@ -1428,19 +1425,7 @@ def test_component_str(
     logistic_regression_binary_pipeline_class,
     linear_regression_pipeline_class,
 ):
-    try:
-        component = component_class()
-    except EnsembleMissingPipelinesError:
-        if component_class == SklearnStackedEnsembleClassifier:
-            component = component_class(
-                input_pipelines=[
-                    logistic_regression_binary_pipeline_class(parameters={})
-                ]
-            )
-        elif component_class == SklearnStackedEnsembleRegressor:
-            component = component_class(
-                input_pipelines=[linear_regression_pipeline_class(parameters={})]
-            )
+    component = component_class()
     assert str(component) == component.name
 
 
@@ -1593,21 +1578,7 @@ def test_estimator_fit_respects_custom_indices(
     helper_functions,
 ):
 
-    if estimator_class == SklearnStackedEnsembleRegressor:
-        input_pipelines = [
-            helper_functions.safe_init_pipeline_with_njobs_1(
-                linear_regression_pipeline_class
-            )
-        ]
-    elif estimator_class == SklearnStackedEnsembleClassifier:
-        input_pipelines = [
-            helper_functions.safe_init_pipeline_with_njobs_1(
-                logistic_regression_binary_pipeline_class
-            )
-        ]
-    else:
-        input_pipelines = []
-
+    input_pipelines = []
     supported_problem_types = estimator_class.supported_problem_types
 
     ts_problem = False
@@ -1648,13 +1619,13 @@ def test_component_modifies_feature_or_target():
     for component_class in all_components():
         if (
             issubclass(component_class, BaseSampler)
-            or issubclass(component_class, TargetTransformer)
+            or hasattr(component_class, "inverse_transform")
             or component_class in [TargetImputer, DropRowsTransformer]
         ):
             assert component_class.modifies_target
         else:
             assert not component_class.modifies_target
-        if issubclass(component_class, TargetTransformer) or component_class in [
+        if hasattr(component_class, "inverse_transform") or component_class in [
             TargetImputer
         ]:
             assert not component_class.modifies_features
@@ -1666,7 +1637,7 @@ def test_component_parameters_supported_by_list_API():
     for component_class in all_components():
         if (
             issubclass(component_class, BaseSampler)
-            or issubclass(component_class, TargetTransformer)
+            or hasattr(component_class, "inverse_transform")
             or component_class in [TargetImputer, DropRowsTransformer]
         ):
             assert not component_class._supported_by_list_API
