@@ -30,10 +30,8 @@ from evalml.pipelines.components import (
     DecisionTreeRegressor,
     Estimator,
     LogisticRegressionClassifier,
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
 )
-from evalml.pipelines.components.ensemble.sklearn_stacked_ensemble_base import (
+from evalml.pipelines.components.ensemble.stacked_ensemble_base import (
     _nonstackable_model_families,
 )
 from evalml.pipelines.components.utils import _all_estimators
@@ -52,12 +50,35 @@ def pytest_configure(config):
     )
 
 
-def create_mock_pipeline(estimator, problem_type):
+def create_mock_pipeline(estimator, problem_type, add_label_encoder=False):
+    est_parameters = (
+        {estimator.name: {"n_jobs": 1}}
+        if estimator.model_family
+        not in [ModelFamily.SVM, ModelFamily.DECISION_TREE, ModelFamily.VOWPAL_WABBIT]
+        else {}
+    )
+
     if problem_type == ProblemTypes.BINARY:
 
         class MockBinaryPipelineWithOnlyEstimator(BinaryClassificationPipeline):
-            custom_name = f"Pipeline with {estimator.name}"
-            component_graph = [estimator]
+            custom_name = (
+                f"Pipeline with {estimator.name}"
+                if add_label_encoder is False
+                else f"Pipeline with {estimator.name} w/ Label Encoder"
+            )
+            component_graph = (
+                [estimator]
+                if add_label_encoder is False
+                else {
+                    "Label Encoder": ["Label Encoder", "X", "y"],
+                    estimator.name: [
+                        estimator,
+                        "Label Encoder.x",
+                        "Label Encoder.y",
+                    ],
+                }
+            )
+            parameters = est_parameters
 
             def __init__(self, parameters, random_seed=0):
                 super().__init__(
@@ -71,8 +92,24 @@ def create_mock_pipeline(estimator, problem_type):
     elif problem_type == ProblemTypes.MULTICLASS:
 
         class MockMulticlassPipelineWithOnlyEstimator(MulticlassClassificationPipeline):
-            custom_name = f"Pipeline with {estimator.name}"
-            component_graph = [estimator]
+            custom_name = (
+                f"Pipeline with {estimator.name}"
+                if add_label_encoder is False
+                else f"Pipeline with {estimator.name} w/ Label Encoder"
+            )
+            component_graph = (
+                [estimator]
+                if add_label_encoder is False
+                else {
+                    "Label Encoder": ["Label Encoder", "X", "y"],
+                    estimator.name: [
+                        estimator,
+                        "Label Encoder.x",
+                        "Label Encoder.y",
+                    ],
+                }
+            )
+            parameters = est_parameters
 
             def __init__(self, parameters, random_seed=0):
                 super().__init__(
@@ -88,6 +125,7 @@ def create_mock_pipeline(estimator, problem_type):
         class MockRegressionPipelineWithOnlyEstimator(RegressionPipeline):
             custom_name = f"Pipeline with {estimator.name}"
             component_graph = [estimator]
+            parameters = est_parameters
 
         return MockRegressionPipelineWithOnlyEstimator
     elif problem_type == ProblemTypes.TIME_SERIES_REGRESSION:
@@ -95,6 +133,7 @@ def create_mock_pipeline(estimator, problem_type):
         class MockTSRegressionPipelineWithOnlyEstimator(TimeSeriesRegressionPipeline):
             custom_name = f"Pipeline with {estimator.name}"
             component_graph = [estimator]
+            parameters = est_parameters
 
         return MockTSRegressionPipelineWithOnlyEstimator
     elif problem_type == ProblemTypes.TIME_SERIES_BINARY:
@@ -102,8 +141,24 @@ def create_mock_pipeline(estimator, problem_type):
         class MockTSRegressionPipelineWithOnlyEstimator(
             TimeSeriesBinaryClassificationPipeline
         ):
-            custom_name = f"Pipeline with {estimator.name}"
-            component_graph = [estimator]
+            custom_name = (
+                f"Pipeline with {estimator.name}"
+                if add_label_encoder is False
+                else f"Pipeline with {estimator.name} w/ Label Encoder"
+            )
+            component_graph = (
+                [estimator]
+                if add_label_encoder is False
+                else {
+                    "Label Encoder": ["Label Encoder", "X", "y"],
+                    estimator.name: [
+                        estimator,
+                        "Label Encoder.x",
+                        "Label Encoder.y",
+                    ],
+                }
+            )
+            parameters = est_parameters
 
         return MockTSRegressionPipelineWithOnlyEstimator
     elif problem_type == ProblemTypes.TIME_SERIES_MULTICLASS:
@@ -111,8 +166,24 @@ def create_mock_pipeline(estimator, problem_type):
         class MockTSRegressionPipelineWithOnlyEstimator(
             TimeSeriesMulticlassClassificationPipeline
         ):
-            custom_name = f"Pipeline with {estimator.name}"
-            component_graph = [estimator]
+            custom_name = (
+                f"Pipeline with {estimator.name}"
+                if add_label_encoder is False
+                else f"Pipeline with {estimator.name} and label encoder"
+            )
+            component_graph = (
+                [estimator]
+                if add_label_encoder is False
+                else {
+                    "Label Encoder": ["Label Encoder", "X", "y"],
+                    estimator.name: [
+                        estimator,
+                        "Label Encoder.x",
+                        "Label Encoder.y",
+                    ],
+                }
+            )
+            parameters = est_parameters
 
         return MockTSRegressionPipelineWithOnlyEstimator
 
@@ -120,15 +191,13 @@ def create_mock_pipeline(estimator, problem_type):
 @pytest.fixture
 def all_pipeline_classes():
     all_possible_pipeline_classes = []
-    for estimator in [
-        estimator
-        for estimator in _all_estimators()
-        if estimator != SklearnStackedEnsembleClassifier
-        and estimator != SklearnStackedEnsembleRegressor
-    ]:
+    for estimator in _all_estimators():
         for problem_type in estimator.supported_problem_types:
             all_possible_pipeline_classes.append(
-                create_mock_pipeline(estimator, problem_type)
+                create_mock_pipeline(estimator, problem_type, add_label_encoder=False)
+            )
+            all_possible_pipeline_classes.append(
+                create_mock_pipeline(estimator, problem_type, add_label_encoder=True)
             )
     return all_possible_pipeline_classes
 
@@ -139,6 +208,17 @@ def all_binary_pipeline_classes(all_pipeline_classes):
         pipeline_class
         for pipeline_class in all_pipeline_classes
         if issubclass(pipeline_class, BinaryClassificationPipeline)
+        and "label encoder" not in pipeline_class.custom_name
+    ]
+
+
+@pytest.fixture
+def all_binary_pipeline_classes_with_encoder(all_pipeline_classes):
+    return [
+        pipeline_class
+        for pipeline_class in all_pipeline_classes
+        if issubclass(pipeline_class, BinaryClassificationPipeline)
+        and "label encoder" in pipeline_class.custom_name
     ]
 
 
@@ -148,6 +228,17 @@ def all_multiclass_pipeline_classes(all_pipeline_classes):
         pipeline_class
         for pipeline_class in all_pipeline_classes
         if issubclass(pipeline_class, MulticlassClassificationPipeline)
+        and "label encoder" not in pipeline_class.custom_name
+    ]
+
+
+@pytest.fixture
+def all_multiclass_pipeline_classes_with_encoder(all_pipeline_classes):
+    return [
+        pipeline_class
+        for pipeline_class in all_pipeline_classes
+        if issubclass(pipeline_class, MulticlassClassificationPipeline)
+        and "label encoder" in pipeline_class.custom_name
     ]
 
 
@@ -193,6 +284,8 @@ def assert_allowed_pipelines_equal_helper():
     def assert_allowed_pipelines_equal_helper(
         actual_allowed_pipelines, expected_allowed_pipelines
     ):
+        actual_allowed_pipelines.sort(key=lambda p: p.name)
+        expected_allowed_pipelines.sort(key=lambda p: p.name)
         for actual, expected in zip(
             actual_allowed_pipelines, expected_allowed_pipelines
         ):
@@ -395,6 +488,25 @@ def example_graph():
     return component_graph
 
 
+@pytest.fixture
+def example_pass_target_graph():
+    component_graph = {
+        "Imputer": ["Imputer", "X", "y"],
+        "Target Imputer": ["Target Imputer", "X", "y"],
+        "OneHot_RandomForest": ["One Hot Encoder", "Imputer.x", "Target Imputer.y"],
+        "OneHot_ElasticNet": ["One Hot Encoder", "Imputer.x", "y"],
+        "Random Forest": ["Random Forest Classifier", "OneHot_RandomForest.x", "y"],
+        "Elastic Net": ["Elastic Net Classifier", "OneHot_ElasticNet.x", "y"],
+        "Logistic Regression": [
+            "Logistic Regression Classifier",
+            "Random Forest.x",
+            "Elastic Net.x",
+            "y",
+        ],
+    }
+    return component_graph
+
+
 @pytest.fixture
 def example_regression_graph():
     component_graph = {
@@ -562,17 +674,32 @@ def dummy_ts_binary_pipeline_class(dummy_classifier_estimator_class):
 
 
 @pytest.fixture
-def logistic_regression_multiclass_pipeline_class():
+def logistic_regression_component_graph():
+    component_graph = {
+        "Label Encoder": ["Label Encoder", "X", "y"],
+        "Imputer": ["Imputer", "X", "Label Encoder.y"],
+        "One Hot Encoder": ["One Hot Encoder", "Imputer.x", "Label Encoder.y"],
+        "Standard Scaler": [
+            "Standard Scaler",
+            "One Hot Encoder.x",
+            "Label Encoder.y",
+        ],
+        "Logistic Regression Classifier": [
+            "Logistic Regression Classifier",
+            "Standard Scaler.x",
+            "Label Encoder.y",
+        ],
+    }
+    return component_graph
+
+
+@pytest.fixture
+def logistic_regression_multiclass_pipeline_class(logistic_regression_component_graph):
     class LogisticRegressionMulticlassPipeline(MulticlassClassificationPipeline):
         """Logistic Regression Pipeline for binary classification."""
 
         custom_name = "Logistic Regression Multiclass Pipeline"
-        component_graph = [
-            "Imputer",
-            "One Hot Encoder",
-            "Standard Scaler",
-            "Logistic Regression Classifier",
-        ]
+        component_graph = logistic_regression_component_graph
 
         def __init__(self, parameters, random_seed=0):
             super().__init__(
@@ -589,14 +716,9 @@ def logistic_regression_multiclass_pipeline_class():
 
 
 @pytest.fixture
-def logistic_regression_binary_pipeline_class():
+def logistic_regression_binary_pipeline_class(logistic_regression_component_graph):
     class LogisticRegressionBinaryPipeline(BinaryClassificationPipeline):
-        component_graph = [
-            "Imputer",
-            "One Hot Encoder",
-            "Standard Scaler",
-            "Logistic Regression Classifier",
-        ]
+        component_graph = logistic_regression_component_graph
         custom_name = "Logistic Regression Binary Pipeline"
 
         def __init__(self, parameters, random_seed=0):
@@ -646,35 +768,6 @@ def linear_regression_pipeline_class():
     return LinearRegressionPipeline
 
 
-@pytest.fixture
-def dummy_stacked_ensemble_binary_estimator(logistic_regression_binary_pipeline_class):
-    p1 = logistic_regression_binary_pipeline_class({})
-    ensemble_estimator = SklearnStackedEnsembleClassifier(
-        input_pipelines=[p1], random_seed=0
-    )
-    return ensemble_estimator
-
-
-@pytest.fixture
-def dummy_stacked_ensemble_multiclass_estimator(
-    logistic_regression_multiclass_pipeline_class,
-):
-    p1 = logistic_regression_multiclass_pipeline_class({})
-    ensemble_estimator = SklearnStackedEnsembleClassifier(
-        input_pipelines=[p1], random_seed=0
-    )
-    return ensemble_estimator
-
-
-@pytest.fixture
-def dummy_stacked_ensemble_regressor_estimator(linear_regression_pipeline_class):
-    p1 = linear_regression_pipeline_class({})
-    ensemble_estimator = SklearnStackedEnsembleRegressor(
-        input_pipelines=[p1], random_seed=0
-    )
-    return ensemble_estimator
-
-
 @pytest.fixture
 def time_series_regression_pipeline_class():
     class TSRegressionPipeline(TimeSeriesRegressionPipeline):
@@ -691,14 +784,31 @@ def time_series_regression_pipeline_class():
 
 
 @pytest.fixture
-def time_series_binary_classification_pipeline_class():
+def time_series_classification_component_graph():
+    component_graph = {
+        "Label Encoder": ["Label Encoder", "X", "y"],
+        "Delayed Feature Transformer": [
+            "Delayed Feature Transformer",
+            "Label Encoder.x",
+            "Label Encoder.y",
+        ],
+        "Logistic Regression Classifier": [
+            "Logistic Regression Classifier",
+            "Delayed Feature Transformer.x",
+            "Label Encoder.y",
+        ],
+    }
+    return component_graph
+
+
+@pytest.fixture
+def time_series_binary_classification_pipeline_class(
+    time_series_classification_component_graph,
+):
     class TSBinaryPipeline(TimeSeriesBinaryClassificationPipeline):
         """Logistic Regression Pipeline for time series binary classification problems."""
 
-        component_graph = [
-            "Delayed Feature Transformer",
-            "Logistic Regression Classifier",
-        ]
+        component_graph = time_series_classification_component_graph
 
         def __init__(self, parameters, random_seed=0):
             super().__init__(
@@ -709,14 +819,13 @@ def time_series_binary_classification_pipeline_class():
 
 
 @pytest.fixture
-def time_series_multiclass_classification_pipeline_class():
+def time_series_multiclass_classification_pipeline_class(
+    time_series_classification_component_graph,
+):
     class TSMultiPipeline(TimeSeriesMulticlassClassificationPipeline):
         """Logistic Regression Pipeline for time series multiclass classification problems."""
 
-        component_graph = [
-            "Delayed Feature Transformer",
-            "Logistic Regression Classifier",
-        ]
+        component_graph = time_series_classification_component_graph
 
         def __init__(self, parameters, random_seed=0):
             super().__init__(
@@ -768,6 +877,22 @@ def nonlinear_binary_pipeline_class(example_graph):
     return NonLinearBinaryPipeline
 
 
+@pytest.fixture
+def nonlinear_binary_with_target_pipeline_class(example_pass_target_graph):
+    class NonLinearBinaryWithTargetPipeline(BinaryClassificationPipeline):
+        custom_name = "Non Linear Binary With Target Pipeline"
+        component_graph = example_pass_target_graph
+
+        def __init__(self, parameters, random_seed=0):
+            super().__init__(
+                self.component_graph,
+                parameters=parameters,
+                custom_name=self.custom_name,
+            )
+
+    return NonLinearBinaryWithTargetPipeline
+
+
 @pytest.fixture
 def nonlinear_multiclass_pipeline_class(example_graph):
     class NonLinearMulticlassPipeline(MulticlassClassificationPipeline):
@@ -926,18 +1051,6 @@ def helper_functions():
                 component = component_class()
             return component
 
-        @staticmethod
-        def safe_init_pipeline_with_njobs_1(pipeline_class):
-            try:
-                estimator = pipeline_class.component_graph[-1]
-                estimator_name = (
-                    estimator if isinstance(estimator, str) else estimator.name
-                )
-                pl = pipeline_class({estimator_name: {"n_jobs": 1}})
-            except ValueError:
-                pl = pipeline_class({})
-            return pl
-
     return Helpers
 
 
@@ -1054,7 +1167,7 @@ def mock_imbalanced_data_X_y():
         For our targets, we maintain a 1:5, or 0.2, class ratio of minority : majority.
         We only generate minimum amount for X to set the logical_types, so the length of X and y will be different.
 
-        Arguments:
+        Args:
             problem_type (str): Either 'binary' or 'multiclass'
             categorical_columns (str): Determines how many categorical cols to use. Either 'all', 'some', or 'none'.
             size (str): Either 'large' or 'small'. 'large' returns a dataset of size 21,000, while 'small' returns a size of 4200
@@ -1114,7 +1227,7 @@ class _AutoMLTestEnv:
     def __init__(self, problem_type):
         """Create a test environment.
 
-        Arguments:
+        Args:
             problem_type (str): The problem type corresponding to the search class you want to test.
 
         Attributes:
@@ -1218,7 +1331,7 @@ class _AutoMLTestEnv:
         """A context manager for creating an environment that patches time-consuming pipeline methods.
         Sets the mock_fit, mock_score, mock_encode_targets, mock_predict_proba, mock_optimize_threshold attributes.
 
-        Arguments:
+        Args:
             score_return_value: Passed as the return_value argument of the pipeline.score patch.
             mock_score_side_effect: Passed as the side_effect argument of the pipeline.score patch. Takes precedence over
                 score_return_value.
