@@ -4,17 +4,17 @@ from evalml.data_checks import DataCheckAction, DataCheckActionCode
 def test_data_check_action_attributes():
     data_check_action = DataCheckAction(DataCheckActionCode.DROP_COL)
     assert data_check_action.action_code == DataCheckActionCode.DROP_COL
-    assert data_check_action.metadata == {}
+    assert data_check_action.metadata == {"rows": None, "columns": None}
 
     data_check_action = DataCheckAction(DataCheckActionCode.DROP_COL, {})
     assert data_check_action.action_code == DataCheckActionCode.DROP_COL
-    assert data_check_action.metadata == {}
+    assert data_check_action.metadata == {"rows": None, "columns": None}
 
     data_check_action = DataCheckAction(
         DataCheckActionCode.DROP_COL, metadata={"columns": [1, 2]}
     )
     assert data_check_action.action_code == DataCheckActionCode.DROP_COL
-    assert data_check_action.metadata == {"columns": [1, 2]}
+    assert data_check_action.metadata == {"columns": [1, 2], "rows": None}
 
 
 def test_data_check_action_equality():
@@ -58,13 +58,17 @@ def test_data_check_action_to_dict():
 
     assert data_check_action.to_dict() == {
         "code": DataCheckActionCode.DROP_COL.name,
-        "metadata": {},
+        "metadata": {"columns": None, "rows": None},
     }
     assert data_check_action_empty_metadata.to_dict() == {
         "code": DataCheckActionCode.DROP_COL.name,
-        "metadata": {},
+        "metadata": {"columns": None, "rows": None},
     }
     assert data_check_action_with_metadata.to_dict() == {
         "code": DataCheckActionCode.DROP_COL.name,
-        "metadata": {"some detail": ["this is different"]},
+        "metadata": {
+            "some detail": ["this is different"],
+            "columns": None,
+            "rows": None,
+        },
     }
