@@ -335,7 +335,8 @@ def test_fast_permutation_importance_matches_slow_output(
         objective = "R2"
 
     mock_supports_fast_importance.return_value = True
-    parameters["Random Forest Classifier"] = {"n_jobs": 1}
+    parameters["Estimator"] = {"n_jobs": 1}
+
     pipeline = pipeline_class(pipeline_class.component_graph, parameters=parameters)
     pipeline.fit(X, y)
     fast_scores = calculate_permutation_importance(
@@ -353,7 +354,7 @@ def test_fast_permutation_importance_matches_slow_output(
     slow_scores = dict(zip(slow_scores.feature, slow_scores.importance.round(5)))
     assert slow_scores == fast_scores
 
-    precomputed_features = pipeline.compute_estimator_features(X, y)
+    precomputed_features = pipeline.transform_all_but_final(X, y)
     # Run one column of each logical type
     for col in [
         "card_id",
@@ -412,7 +413,7 @@ class EnsembleDag(BinaryClassificationPipeline):
         "Estimator_1": ["Random Forest Classifier", "DT_1.x", "y"],
         "Estimator_2": ["Extra Trees Classifier", "DT_2.x", "y"],
         "Ensembler": [
-            "Logistic Regression Classifier",
+            "Stacked Ensemble Classifier",
             "Estimator_1.x",
             "Estimator_2.x",
             "y",
@@ -449,23 +450,11 @@ class PipelineWithCustomComponent(BinaryClassificationPipeline):
         )
 
 
-class SklearnStackedEnsemblePipeline(BinaryClassificationPipeline):
-    component_graph = ["Sklearn Stacked Ensemble Classifier"]
-
-    def __init__(self, parameters, random_seed=0):
-        super().__init__(
-            self.component_graph,
-            parameters=parameters,
-            random_seed=random_seed,
-        )
-
-
 pipelines_that_do_not_support_fast_permutation_importance = [
     PipelineWithDimReduction,
     PipelineWithDFS,
     PipelineWithCustomComponent,
     EnsembleDag,
-    SklearnStackedEnsemblePipeline,
 ]
 
 
@@ -473,12 +462,7 @@ pipelines_that_do_not_support_fast_permutation_importance = [
     "pipeline_class", pipelines_that_do_not_support_fast_permutation_importance
 )
 def test_supports_fast_permutation_importance(pipeline_class):
-    params = {
-        "Sklearn Stacked Ensemble Classifier": {
-            "input_pipelines": [PipelineWithDFS({})]
-        }
-    }
-    assert not pipeline_class(params)._supports_fast_permutation_importance
+    assert not pipeline_class({})._supports_fast_permutation_importance
 
 
 def test_get_permutation_importance_invalid_objective(
@@ -677,18 +661,13 @@ def test_get_permutation_importance_one_column_pipeline_does_not_support_fast(
     X_y_binary, pipeline_class
 ):
     X, y = X_y_binary
-    params = {
-        "Sklearn Stacked Ensemble Classifier": {
-            "input_pipelines": [PipelineWithDFS({})]
-        }
-    }
-    assert not pipeline_class(params)._supports_fast_permutation_importance
+    assert not pipeline_class({})._supports_fast_permutation_importance
     with pytest.raises(
         ValueError,
         match="Pipeline does not support fast permutation importance calculation",
     ):
         calculate_permutation_importance_one_column(
-            pipeline_class(params), X, y, 0, "log loss binary", fast=True
+            pipeline_class({}), X, y, 0, "log loss binary", fast=True
         )
 
 
@@ -720,3 +699,37 @@ def test_permutation_importance_url_email(df_with_url_and_email):
     assert not data.isnull().any().any()
     assert "url" in data["feature"].tolist()
     assert "email" in data["feature"].tolist()
+
+
+def test_permutation_importance_postalcode_countrycode_subregion(
+    fraud_100, logistic_regression_binary_pipeline_class
+):
+    X, y = fraud_100
+    X.ww.set_types(
+        logical_types={
+            "store_id": "PostalCode",
+            "country": "CountryCode",
+            "region": "SubRegionCode",
+        }
+    )
+
+    pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    pipeline.fit(X, y)
+    data = calculate_permutation_importance(pipeline, X, y, objective="Log Loss Binary")
+    assert not data.isnull().any().any()
+    assert "store_id" in data["feature"].tolist()
+    assert "country" in data["feature"].tolist()
+    assert "region" in data["feature"].tolist()
+
+
+def test_permutation_importance_standard_scaler(fraud_100):
+    X, y = fraud_100
+    component_graph = [
+        "Imputer",
+        "One Hot Encoder",
+        "Standard Scaler",
+        "Logistic Regression Classifier",
+    ]
+    pipeline = BinaryClassificationPipeline(component_graph)
+    pipeline.fit(X, y)
+    calculate_permutation_importance(pipeline, X, y, objective="log loss binary")
