@@ -1,3 +1,5 @@
+from unittest.mock import patch
+
 import numpy as np
 import pandas as pd
 import pytest
@@ -21,31 +23,31 @@ from evalml.pipelines.components import (
     Imputer,
     LinearRegressor,
     LogisticRegressionClassifier,
-    LogTransformer,
     OneHotEncoder,
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
     StandardScaler,
     TargetImputer,
     TextFeaturizer,
     Transformer,
     URLFeaturizer,
 )
+from evalml.pipelines.components.transformers.encoders.label_encoder import (
+    LabelEncoder,
+)
 from evalml.pipelines.utils import (
     _get_pipeline_base_class,
     _make_component_list_from_actions,
     generate_pipeline_code,
     get_estimators,
+    is_classification,
     make_pipeline,
+    rows_of_interest,
 )
 from evalml.problem_types import ProblemTypes, is_regression, is_time_series
 
 
 @pytest.fixture
 def get_test_data_from_configuration():
-    def _get_test_data_from_configuration(
-        input_type, problem_type, column_names=None, lognormal_distribution=False
-    ):
+    def _get_test_data_from_configuration(input_type, problem_type, column_names=None):
         X_all = pd.DataFrame(
             {
                 "all_null": [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan]
@@ -83,16 +85,23 @@ def get_test_data_from_configuration():
                     "https://github.com/alteryx/featuretools",
                 ]
                 * 2,
+                "ip": [
+                    "0.0.0.0",
+                    "1.1.1.101",
+                    "1.1.101.1",
+                    "1.101.1.1",
+                    "101.1.1.1",
+                    "192.168.1.1",
+                    "255.255.255.255",
+                ]
+                * 2,
             }
         )
         y = pd.Series([0, 0, 1, 0, 0, 1, 1] * 2)
         if problem_type == ProblemTypes.MULTICLASS:
             y = pd.Series([0, 2, 1, 2, 0, 2, 1] * 2)
         elif is_regression(problem_type):
-            if lognormal_distribution:
-                y = pd.Series([1, 1, 1, 2, 3, 6, 9] * 2)
-            else:
-                y = pd.Series([1, 2, 3, 3, 3, 4, 5] * 2)
+            y = pd.Series([1, 2, 3, 3, 3, 4, 5] * 2)
         X = X_all[column_names]
 
         if input_type == "ww":
@@ -115,7 +124,6 @@ def get_test_data_from_configuration():
     return _get_test_data_from_configuration
 
 
-@pytest.mark.parametrize("lognormal_distribution", [True, False])
 @pytest.mark.parametrize("input_type", ["pd", "ww"])
 @pytest.mark.parametrize("problem_type", ProblemTypes.all_problem_types)
 @pytest.mark.parametrize(
@@ -128,17 +136,18 @@ def get_test_data_from_configuration():
         ("only text", ["text"]),
         ("only dates", ["dates"]),
         ("only numerical", ["numerical"]),
+        ("only ip", ["ip"]),
         ("only all_null", ["all_null"]),
         ("only categorical", ["categorical"]),
         ("text with other features", ["text", "numerical", "categorical"]),
         ("url with other features", ["url", "numerical", "categorical"]),
+        ("ip with other features", ["ip", "numerical", "categorical"]),
         ("email with other features", ["email", "numerical", "categorical"]),
     ],
 )
 def test_make_pipeline(
     problem_type,
     input_type,
-    lognormal_distribution,
     test_description,
     column_names,
     get_test_data_from_configuration,
@@ -148,7 +157,6 @@ def test_make_pipeline(
         input_type,
         problem_type,
         column_names=column_names,
-        lognormal_distribution=lognormal_distribution,
     )
     estimators = get_estimators(problem_type=problem_type)
     pipeline_class = _get_pipeline_base_class(problem_type)
@@ -167,6 +175,7 @@ def test_make_pipeline(
 
             pipeline = make_pipeline(X, y, estimator_class, problem_type, parameters)
             assert isinstance(pipeline, pipeline_class)
+            label_encoder = [LabelEncoder] if is_classification(problem_type) else []
             delayed_features = (
                 [DelayedFeatureTransformer]
                 if is_time_series(problem_type)
@@ -177,10 +186,9 @@ def test_make_pipeline(
                 [OneHotEncoder]
                 if estimator_class.model_family != ModelFamily.CATBOOST
                 and (
-                    "categorical" in column_names
-                    or (
-                        any(ltype in column_names for ltype in ["url", "email"])
-                        and input_type == "ww"
+                    any(
+                        ltype in column_names
+                        for ltype in ["url", "email", "categorical"]
                     )
                 )
                 else []
@@ -197,11 +205,6 @@ def test_make_pipeline(
                 if estimator_class.model_family == ModelFamily.LINEAR_MODEL
                 else []
             )
-            log_transformer = (
-                [LogTransformer]
-                if lognormal_distribution and is_regression(problem_type)
-                else []
-            )
             drop_null = [DropNullColumns] if "all_null" in column_names else []
             text_featurizer = (
                 [TextFeaturizer]
@@ -209,30 +212,28 @@ def test_make_pipeline(
                 else []
             )
             email_featurizer = [EmailFeaturizer] if "email" in column_names else []
-            url_featurizer = (
-                [URLFeaturizer] if "url" in column_names and input_type == "ww" else []
-            )
+            url_featurizer = [URLFeaturizer] if "url" in column_names else []
             imputer = (
                 []
-                if (column_names == ["dates"] and input_type == "ww")
-                or ((column_names in [["text"], ["dates"]]) and input_type == "pd")
+                if ((column_names in [["ip"]]) and input_type == "ww")
+                or ((column_names in [["ip"], ["text"]]) and input_type == "pd")
                 else [Imputer]
             )
             drop_col = (
                 [DropColumns]
-                if any(ltype in column_names for ltype in ["url", "text"])
+                if any(ltype in column_names for ltype in ["text"])
                 and input_type == "pd"
                 else []
             )
             expected_components = (
-                log_transformer
+                label_encoder
                 + email_featurizer
                 + url_featurizer
                 + drop_null
                 + text_featurizer
                 + drop_col
-                + imputer
                 + datetime
+                + imputer
                 + delayed_features
                 + ohe
                 + standard_scaler
@@ -268,76 +269,6 @@ def test_make_pipeline_problem_type_mismatch():
         make_pipeline(pd.DataFrame(), pd.Series(), Transformer, ProblemTypes.MULTICLASS)
 
 
-@pytest.mark.parametrize(
-    "problem_type",
-    [ProblemTypes.BINARY, ProblemTypes.MULTICLASS, ProblemTypes.REGRESSION],
-)
-def test_stacked_estimator_in_pipeline(
-    problem_type,
-    X_y_binary,
-    X_y_multi,
-    X_y_regression,
-    stackable_classifiers,
-    stackable_regressors,
-    logistic_regression_binary_pipeline_class,
-    logistic_regression_multiclass_pipeline_class,
-    linear_regression_pipeline_class,
-):
-    if problem_type == ProblemTypes.BINARY:
-        X, y = X_y_binary
-        base_pipeline_class = BinaryClassificationPipeline
-        stacking_component_name = SklearnStackedEnsembleClassifier.name
-        input_pipelines = [
-            BinaryClassificationPipeline([classifier])
-            for classifier in stackable_classifiers
-        ]
-        comparison_pipeline = logistic_regression_binary_pipeline_class(
-            parameters={"Logistic Regression Classifier": {"n_jobs": 1}}
-        )
-        objective = "Log Loss Binary"
-    elif problem_type == ProblemTypes.MULTICLASS:
-        X, y = X_y_multi
-        base_pipeline_class = MulticlassClassificationPipeline
-        stacking_component_name = SklearnStackedEnsembleClassifier.name
-        input_pipelines = [
-            MulticlassClassificationPipeline([classifier])
-            for classifier in stackable_classifiers
-        ]
-        comparison_pipeline = logistic_regression_multiclass_pipeline_class(
-            parameters={"Logistic Regression Classifier": {"n_jobs": 1}}
-        )
-        objective = "Log Loss Multiclass"
-    elif problem_type == ProblemTypes.REGRESSION:
-        X, y = X_y_regression
-        base_pipeline_class = RegressionPipeline
-        stacking_component_name = SklearnStackedEnsembleRegressor.name
-        input_pipelines = [
-            RegressionPipeline([regressor]) for regressor in stackable_regressors
-        ]
-        comparison_pipeline = linear_regression_pipeline_class(
-            parameters={"Linear Regressor": {"n_jobs": 1}}
-        )
-        objective = "R2"
-    parameters = {
-        stacking_component_name: {"input_pipelines": input_pipelines, "n_jobs": 1}
-    }
-    graph = ["Simple Imputer", stacking_component_name]
-
-    pipeline = base_pipeline_class(component_graph=graph, parameters=parameters)
-    pipeline.fit(X, y)
-    comparison_pipeline.fit(X, y)
-    assert not np.isnan(pipeline.predict(X)).values.any()
-
-    pipeline_score = pipeline.score(X, y, [objective])[objective]
-    comparison_pipeline_score = comparison_pipeline.score(X, y, [objective])[objective]
-
-    if problem_type == ProblemTypes.BINARY or problem_type == ProblemTypes.MULTICLASS:
-        assert not np.isnan(pipeline.predict_proba(X)).values.any()
-        assert pipeline_score <= comparison_pipeline_score
-    else:
-        assert pipeline_score >= comparison_pipeline_score
-
-
 def test_make_component_list_from_actions():
     assert _make_component_list_from_actions([]) == []
 
@@ -637,6 +568,9 @@ def test_generate_code_pipeline_with_custom_components():
                 parameters=parameters, component_obj=None, random_seed=random_seed
             )
 
+        def transform(self, X, y=None):
+            return X
+
     class CustomEstimator(Estimator):
         name = "My Custom Estimator"
         hyperparameter_ranges = {}
@@ -660,3 +594,215 @@ def test_generate_code_pipeline_with_custom_components():
     )
     pipeline = generate_pipeline_code(mock_pipeline_with_custom_components)
     assert pipeline == expected_code
+
+
+def test_rows_of_interest_errors(X_y_binary):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    pipeline_mc = MulticlassClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X, y = X_y_binary
+
+    with pytest.raises(ValueError, match="Invalid arg for"):
+        rows_of_interest(pipeline, X, y, types="ball")
+
+    with pytest.raises(ValueError, match="Need an input y in order to"):
+        rows_of_interest(pipeline, X, types="correct")
+
+    with pytest.raises(ValueError, match="Pipeline provided must be a fitted"):
+        rows_of_interest(pipeline, X, y, types="all")
+
+    with pytest.raises(ValueError, match="Pipeline provided must be a fitted"):
+        rows_of_interest(pipeline_mc, X, y, types="all")
+
+    with pytest.raises(ValueError, match="Pipeline provided must be a fitted"):
+        rows_of_interest(pipeline_mc, X, y, types="all")
+
+    pipeline._is_fitted = True
+    with pytest.raises(ValueError, match="Provided threshold 1.1 must be between"):
+        rows_of_interest(pipeline, X, y, threshold=1.1)
+
+    with pytest.raises(ValueError, match="Provided threshold -0.1 must be between"):
+        rows_of_interest(pipeline, X, y, threshold=-0.1)
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+@pytest.mark.parametrize("threshold", [0.3, None, 0.7])
+@pytest.mark.parametrize("y", [pd.Series([i % 2 for i in range(100)]), None])
+def test_rows_of_interest_threshold(mock_fit, mock_pred_proba, threshold, y):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Imputer", "Standard Scaler", "Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame([i for i in range(100)])
+    y = y
+    pipeline._is_fitted = True
+
+    vals = [0.2] * 25 + [0.5] * 50 + [0.8] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(
+        pipeline, X, y, threshold=threshold, epsilon=0.5, sort_values=True
+    )
+    if threshold == 0.3:
+        assert vals == list(range(100))
+    elif threshold == 0.7:
+        assert vals == list(range(75, 100)) + list(range(25, 75)) + list(range(25))
+    else:
+        assert vals == list(range(25, 75)) + list(range(25)) + list(range(75, 100))
+
+    pipeline._threshold = 0.9
+    vals = rows_of_interest(
+        pipeline, X, y, threshold=None, epsilon=0.5, sort_values=True
+    )
+    assert vals == list(range(75, 100)) + list(range(25, 75))
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+@pytest.mark.parametrize(
+    "types,expected_val",
+    [
+        ("incorrect", list(range(75, 100))),
+        ("correct", list(range(75))),
+        ("true_positive", list(range(25, 75))),
+        ("true_negative", list(range(25)) + list(range(75, 100))),
+        ("all", list(range(100))),
+    ],
+)
+def test_rows_of_interest_types(mock_fit, mock_pred_proba, types, expected_val):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame([i for i in range(100)])
+    y = pd.Series([0] * 25 + [1] * 50 + [0] * 25)
+    pipeline._is_fitted = True
+
+    vals = [0.2] * 25 + [0.5] * 50 + [0.8] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(pipeline, X, y, types=types, epsilon=0.5, sort_values=False)
+    assert vals == expected_val
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+@pytest.mark.parametrize("epsilon,expected_len", [(0.01, 50), (0.3, 75), (0.5, 100)])
+def test_rows_of_interest_epsilon(mock_fit, mock_pred_proba, epsilon, expected_len):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame([i for i in range(100)])
+    y = pd.Series([0] * 25 + [1] * 50 + [0] * 25)
+    pipeline._is_fitted = True
+
+    vals = [0.2] * 25 + [0.5] * 50 + [0.85] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(pipeline, X, y, epsilon=epsilon)
+    assert len(vals) == expected_len
+
+    if epsilon == 0.01:
+        vals = [0.2] * 25 + [0.65] * 50 + [0.85] * 25
+        predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+        mock_pred_proba.return_value = predicted_proba_values
+        vals = rows_of_interest(pipeline, X, y, epsilon=epsilon)
+        assert len(vals) == 0
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+@pytest.mark.parametrize(
+    "sorts,expected_val",
+    [
+        (True, list(range(75, 100)) + list(range(25, 75)) + list(range(25))),
+        (False, list(range(100))),
+    ],
+)
+def test_rows_of_interest_sorted(mock_fit, mock_pred_proba, sorts, expected_val):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame([i for i in range(100)])
+    y = pd.Series([0] * 25 + [1] * 50 + [0] * 25)
+    pipeline._is_fitted = True
+
+    vals = [0.2] * 25 + [0.5] * 50 + [0.8] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(
+        pipeline, X, y, threshold=0.9, epsilon=0.9, sort_values=sorts
+    )
+    assert vals == expected_val
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+def test_rows_of_interest_index(mock_fit, mock_pred_proba):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame(
+        [i for i in range(100)], index=["index_{}".format(i) for i in range(100)]
+    )
+    pipeline._is_fitted = True
+
+    vals = [0.2] * 25 + [0.5] * 50 + [0.8] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(pipeline, X, epsilon=0.5)
+    assert vals == list(range(25, 75)) + list(range(25)) + list(range(75, 100))
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+@pytest.mark.parametrize(
+    "types,sorts,epsilon,expected_vals",
+    [
+        ("correct", True, 0.01, list(range(25, 75))),
+        ("true_negative", True, 0.3, list(range(25))),
+        ("all", False, 0.3, list(range(75))),
+    ],
+)
+def test_rows_of_interest(
+    mock_fit, mock_pred_proba, types, sorts, epsilon, expected_vals
+):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame([i for i in range(100)])
+    y = pd.Series([0] * 25 + [1] * 50 + [0] * 25)
+    pipeline._is_fitted = True
+
+    vals = [0.2] * 25 + [0.5] * 50 + [0.85] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(
+        pipeline, X, y, types=types, sort_values=sorts, epsilon=epsilon
+    )
+    assert vals == expected_vals
+
+    if types == "all":
+        vals = rows_of_interest(
+            pipeline, X, types=types, sort_values=sorts, epsilon=epsilon
+        )
+        assert vals == expected_vals
+
+
+@patch("evalml.pipelines.BinaryClassificationPipeline.predict_proba")
+@patch("evalml.pipelines.BinaryClassificationPipeline.fit")
+def test_rows_of_interest_empty(mock_fit, mock_pred_proba):
+    pipeline = BinaryClassificationPipeline(
+        component_graph=["Logistic Regression Classifier"]
+    )
+    X = pd.DataFrame([i for i in range(100)])
+    y = pd.Series([0] * 25 + [1] * 50 + [0] * 25)
+    pipeline._is_fitted = True
+
+    vals = [1] * 25 + [0] * 50 + [1] * 25
+    predicted_proba_values = pd.DataFrame({0: [1 - v for v in vals], 1: vals})
+    mock_pred_proba.return_value = predicted_proba_values
+    vals = rows_of_interest(pipeline, X, y, epsilon=0.5, types="correct")
+    assert len(vals) == 0
