@@ -33,8 +33,10 @@ from evalml.pipelines import (
 from evalml.pipelines.component_graph import ComponentGraph
 from evalml.pipelines.components import (
     DropNullColumns,
+    DropRowsTransformer,
     ElasticNetClassifier,
     Imputer,
+    LabelEncoder,
     LogisticRegressionClassifier,
     OneHotEncoder,
     RandomForestClassifier,
@@ -239,7 +241,7 @@ def test_indexing(X_y_binary, logistic_regression_binary_pipeline_class):
     )
     clf.fit(X, y)
 
-    assert isinstance(clf[1], OneHotEncoder)
+    assert isinstance(clf[2], OneHotEncoder)
     assert isinstance(clf["Imputer"], Imputer)
 
     setting_err_msg = "Setting pipeline components is not supported."
@@ -282,6 +284,7 @@ def test_describe_pipeline(
                         "numeric_fill_value": None,
                     },
                 },
+                "Label Encoder": {"name": "Label Encoder", "parameters": {}},
                 "One Hot Encoder": {
                     "name": "One Hot Encoder",
                     "parameters": {
@@ -399,32 +402,8 @@ def test_nonlinear_model_family(example_graph):
                 random_seed=random_seed,
             )
 
-    class DummyTransformerEndPipeline(BinaryClassificationPipeline):
-        component_graph = {
-            "Imputer": ["Imputer", "X", "y"],
-            "OneHot": ["One Hot Encoder", "Imputer.x", "y"],
-            "Random Forest": ["Random Forest Classifier", "OneHot.x", "y"],
-            "Logistic Regression": ["Logistic Regression Classifier", "OneHot.x", "y"],
-            "Scaler": [
-                "Standard Scaler",
-                "Random Forest.x",
-                "Logistic Regression.x",
-                "y",
-            ],
-        }
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                random_seed=random_seed,
-            )
-
     nlbp = DummyNonlinearPipeline({})
-    nltp = DummyTransformerEndPipeline({})
-
     assert nlbp.model_family == ModelFamily.LINEAR_MODEL
-    assert nltp.model_family == ModelFamily.NONE
 
 
 def test_parameters(logistic_regression_binary_pipeline_class):
@@ -633,49 +612,41 @@ def test_score_nonlinear_regression(
     assert scores == {"R2": 1.0}
 
 
-@patch("evalml.pipelines.BinaryClassificationPipeline._encode_targets")
 @patch("evalml.pipelines.BinaryClassificationPipeline.fit")
 @patch("evalml.pipelines.components.Estimator.predict")
-def test_score_binary_single(mock_predict, mock_fit, mock_encode, X_y_binary):
+def test_score_binary_single(mock_predict, mock_fit, X_y_binary):
     X, y = X_y_binary
     mock_predict.return_value = y
-    mock_encode.return_value = y
     clf = make_mock_binary_pipeline()
     clf.fit(X, y)
     objective_names = ["f1"]
     scores = clf.score(X, y, objective_names)
-    mock_encode.assert_called()
     mock_fit.assert_called()
     mock_predict.assert_called()
     assert scores == {"F1": 1.0}
 
 
-@patch("evalml.pipelines.MulticlassClassificationPipeline._encode_targets")
 @patch("evalml.pipelines.MulticlassClassificationPipeline.fit")
 @patch("evalml.pipelines.components.Estimator.predict")
-def test_score_multiclass_single(mock_predict, mock_fit, mock_encode, X_y_binary):
+def test_score_multiclass_single(mock_predict, mock_fit, X_y_binary):
     X, y = X_y_binary
     mock_predict.return_value = y
-    mock_encode.return_value = y
     clf = make_mock_multiclass_pipeline()
     clf.fit(X, y)
     objective_names = ["f1 micro"]
     scores = clf.score(X, y, objective_names)
-    mock_encode.assert_called()
     mock_fit.assert_called()
     mock_predict.assert_called()
     assert scores == {"F1 Micro": 1.0}
 
 
-@patch("evalml.pipelines.MulticlassClassificationPipeline._encode_targets")
 @patch("evalml.pipelines.MulticlassClassificationPipeline.fit")
 @patch("evalml.pipelines.ComponentGraph.predict")
 def test_score_nonlinear_multiclass(
-    mock_predict, mock_fit, mock_encode, nonlinear_multiclass_pipeline_class, X_y_multi
+    mock_predict, mock_fit, nonlinear_multiclass_pipeline_class, X_y_multi
 ):
     X, y = X_y_multi
     mock_predict.return_value = pd.Series(y)
-    mock_encode.return_value = pd.Series(y)
     clf = nonlinear_multiclass_pipeline_class({})
     clf.fit(X, y)
     objective_names = ["f1 micro", "precision micro"]
@@ -697,19 +668,16 @@ def test_score_regression_list(mock_predict, mock_fit, X_y_binary):
     assert scores == {"R2": 1.0, "MSE": 0.0}
 
 
-@patch("evalml.pipelines.BinaryClassificationPipeline._encode_targets")
 @patch("evalml.pipelines.BinaryClassificationPipeline.fit")
 @patch("evalml.pipelines.components.Estimator.predict")
-def test_score_binary_list(mock_predict, mock_fit, mock_encode, X_y_binary):
+def test_score_binary_list(mock_predict, mock_fit, X_y_binary):
     X, y = X_y_binary
     mock_predict.return_value = y
-    mock_encode.return_value = y
     clf = make_mock_binary_pipeline()
     clf.fit(X, y)
     objective_names = ["f1", "precision"]
     scores = clf.score(X, y, objective_names)
     mock_fit.assert_called()
-    mock_encode.assert_called()
     mock_predict.assert_called()
     assert scores == {"F1": 1.0, "Precision": 1.0}
 
@@ -833,7 +801,7 @@ def test_score_multiclass_objective_error(
 @patch("evalml.pipelines.components.Imputer.transform")
 @patch("evalml.pipelines.components.OneHotEncoder.transform")
 @patch("evalml.pipelines.components.StandardScaler.transform")
-def test_compute_estimator_features(
+def test_transform_all_but_final(
     mock_scaler,
     mock_ohe,
     mock_imputer,
@@ -851,7 +819,7 @@ def test_compute_estimator_features(
     pipeline = logistic_regression_binary_pipeline_class({})
     pipeline.fit(X, y)
 
-    X_t = pipeline.compute_estimator_features(X)
+    X_t = pipeline.transform_all_but_final(X)
     assert_frame_equal(X_expected, X_t)
     assert mock_imputer.call_count == 2
     assert mock_ohe.call_count == 2
@@ -864,7 +832,7 @@ def test_compute_estimator_features(
 @patch("evalml.pipelines.components.ElasticNetClassifier.predict_proba")
 @patch("evalml.pipelines.components.RandomForestClassifier.predict")
 @patch("evalml.pipelines.components.ElasticNetClassifier.predict")
-def test_compute_estimator_features_nonlinear(
+def test_transform_all_but_final_nonlinear(
     mock_en_predict,
     mock_rf_predict,
     mock_en_predict_proba,
@@ -900,7 +868,7 @@ def test_compute_estimator_features_nonlinear(
 
     pipeline = nonlinear_binary_pipeline_class({})
     pipeline.fit(X, y)
-    X_t = pipeline.compute_estimator_features(X)
+    X_t = pipeline.transform_all_but_final(X)
 
     assert_frame_equal(X_expected_df, X_t)
     assert mock_imputer.call_count == 2
@@ -920,6 +888,9 @@ def test_no_default_parameters():
             self.c = c
             super().__init__()
 
+        def transform(self, X, y=None):
+            return X
+
     class TestPipeline(BinaryClassificationPipeline):
         component_graph = [MockComponent, "Logistic Regression Classifier"]
 
@@ -1297,8 +1268,10 @@ def test_targets_data_types_classification_pipelines(
     problem_type,
     target_type,
     all_binary_pipeline_classes,
+    all_binary_pipeline_classes_with_encoder,
     make_data_type,
     all_multiclass_pipeline_classes,
+    all_multiclass_pipeline_classes_with_encoder,
     helper_functions,
 ):
     if data_type == "np" and target_type in ["Int64", "boolean"]:
@@ -1309,6 +1282,9 @@ def test_targets_data_types_classification_pipelines(
     if problem_type == ProblemTypes.BINARY:
         objective = "Log Loss Binary"
         pipeline_classes = all_binary_pipeline_classes
+        if target_type in ["category", "object"]:
+            pipeline_classes = all_binary_pipeline_classes_with_encoder
+
         X, y = breast_cancer_local
         if "bool" in target_type:
             y = y.map({"malignant": False, "benign": True})
@@ -1319,6 +1295,9 @@ def test_targets_data_types_classification_pipelines(
             )
         objective = "Log Loss Multiclass"
         pipeline_classes = all_multiclass_pipeline_classes
+
+        if target_type in ["category", "object"]:
+            pipeline_classes = all_multiclass_pipeline_classes_with_encoder
         X, y = wine_local
 
     # Update target types as necessary
@@ -1340,7 +1319,7 @@ def test_targets_data_types_classification_pipelines(
     y = make_data_type(data_type, y)
 
     for pipeline_class in pipeline_classes:
-        pipeline = helper_functions.safe_init_pipeline_with_njobs_1(pipeline_class)
+        pipeline = pipeline_class(pipeline_class.parameters)
         pipeline.fit(X, y)
         predictions = pipeline.predict(X, objective)
         assert set(predictions.unique()).issubset(unique_vals)
@@ -2023,6 +2002,7 @@ def test_predict_has_input_target_name(
         )
     elif problem_type == ProblemTypes.TIME_SERIES_BINARY:
         X, y = X_y_binary
+        X, y = pd.DataFrame(X), pd.Series(y)
         X_validation = X[50:52]
         X, y = X[:50], y[:50]
         clf = time_series_binary_classification_pipeline_class(
@@ -2043,6 +2023,7 @@ def test_predict_has_input_target_name(
         )
     elif problem_type == ProblemTypes.TIME_SERIES_MULTICLASS:
         X, y = X_y_multi
+        X, y = pd.DataFrame(X), pd.Series(y)
         X_validation = X[50:52]
         X, y = X[:50], y[:50]
         clf = time_series_multiclass_classification_pipeline_class(
@@ -2072,6 +2053,7 @@ def test_predict_has_input_target_name(
 
 def test_linear_pipeline_iteration(logistic_regression_binary_pipeline_class):
     expected_order = [
+        LabelEncoder(),
         Imputer(),
         OneHotEncoder(),
         StandardScaler(),
@@ -2086,6 +2068,7 @@ def test_linear_pipeline_iteration(logistic_regression_binary_pipeline_class):
     assert order_again == expected_order
 
     expected_order_params = [
+        LabelEncoder(),
         Imputer(numeric_impute_strategy="median"),
         OneHotEncoder(top_n=2),
         StandardScaler(),
@@ -2146,11 +2129,13 @@ def test_linear_getitem(logistic_regression_binary_pipeline_class):
         {"One Hot Encoder": {"top_n": 4}}
     )
 
-    assert pipeline[0] == Imputer()
-    assert pipeline[1] == OneHotEncoder(top_n=4)
-    assert pipeline[2] == StandardScaler()
-    assert pipeline[3] == LogisticRegressionClassifier()
+    assert pipeline[0] == LabelEncoder()
+    assert pipeline[1] == Imputer()
+    assert pipeline[2] == OneHotEncoder(top_n=4)
+    assert pipeline[3] == StandardScaler()
+    assert pipeline[4] == LogisticRegressionClassifier()
 
+    assert pipeline["Label Encoder"] == LabelEncoder()
     assert pipeline["Imputer"] == Imputer()
     assert pipeline["One Hot Encoder"] == OneHotEncoder(top_n=4)
     assert pipeline["Standard Scaler"] == StandardScaler()
@@ -2754,3 +2739,141 @@ def test_pipeline_transform_with_final_estimator(
         ),
     ):
         pipeline.transform(X, y)
+
+
+@patch("evalml.pipelines.components.LogisticRegressionClassifier.fit")
+def test_training_only_component_in_pipeline_fit(mock_fit, X_y_binary):
+    X, y = X_y_binary
+    pipeline = BinaryClassificationPipeline(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Drop Rows Transformer": [DropRowsTransformer, "Imputer.x", "y"],
+            "Logistic Regression Classifier": [
+                "Logistic Regression Classifier",
+                "Drop Rows Transformer.x",
+                "Drop Rows Transformer.y",
+            ],
+        },
+        parameters={"Drop Rows Transformer": {"indices_to_drop": [0, 9]}},
+    )
+    pipeline.fit(X, y)
+    assert len(mock_fit.call_args[0][0]) == len(X) - 2
+
+
+def test_training_only_component_in_pipeline_predict_and_transform_all_but_final(
+    X_y_binary,
+):
+    # Test that calling predict() and `transform_all_but_final` will not evaluate any training-only transformations
+    X, y = X_y_binary
+    pipeline = BinaryClassificationPipeline(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Drop Rows Transformer": [DropRowsTransformer, "Imputer.x", "y"],
+            "Logistic Regression Classifier": [
+                "Logistic Regression Classifier",
+                "Drop Rows Transformer.x",
+                "Drop Rows Transformer.y",
+            ],
+        },
+        parameters={"Drop Rows Transformer": {"indices_to_drop": [9]}},
+    )
+    pipeline.fit(X, y)
+    preds = pipeline.predict(X)
+    assert len(preds) == len(X)
+    preds = pipeline.predict_proba(X)
+    assert len(preds) == len(X)
+    estimator_features = pipeline.transform_all_but_final(X, y)
+    assert len(estimator_features) == len(X)
+
+
+def test_training_only_component_in_pipeline_transform(X_y_binary):
+    # Test that calling transform() will evaluate all training-only transformations
+    X, y = X_y_binary
+    pipeline = BinaryClassificationPipeline(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Drop Rows Transformer": [DropRowsTransformer, "Imputer.x", "y"],
+        },
+        parameters={"Drop Rows Transformer": {"indices_to_drop": [0, 9]}},
+    )
+    pipeline.fit(X, y)
+    transformed = pipeline.transform(X)
+    assert len(transformed) == len(X) - 2
+
+
+def test_component_graph_pipeline():
+    classification_cg = ComponentGraph(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Undersampler": ["Undersampler", "Imputer.x", "y"],
+            "Logistic Regression Classifier": [
+                "Logistic Regression Classifier",
+                "Undersampler.x",
+                "Undersampler.y",
+            ],
+        }
+    )
+
+    regression_cg = ComponentGraph(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Linear Regressor": [
+                "Linear Regressor",
+                "Imputer.x",
+                "y",
+            ],
+        }
+    )
+
+    no_estimator_cg = ComponentGraph(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Undersampler": ["Undersampler", "Imputer.x", "y"],
+        }
+    )
+
+    assert (
+        BinaryClassificationPipeline(classification_cg).component_graph
+        == classification_cg
+    )
+    assert RegressionPipeline(regression_cg).component_graph == regression_cg
+    assert (
+        BinaryClassificationPipeline(no_estimator_cg).component_graph == no_estimator_cg
+    )
+    with pytest.raises(
+        ValueError, match="Problem type regression not valid for this component graph"
+    ):
+        RegressionPipeline(classification_cg)
+
+
+def test_component_graph_pipeline_initialized():
+    component_graph1 = ComponentGraph(
+        {
+            "Imputer": ["Imputer", "X", "y"],
+            "Undersampler": ["Undersampler", "Imputer.x", "y"],
+            "Logistic Regression Classifier": [
+                "Logistic Regression Classifier",
+                "Undersampler.x",
+                "Undersampler.y",
+            ],
+        }
+    )
+    component_graph1.instantiate({"Imputer": {"numeric_impute_strategy": "mean"}})
+    assert (
+        component_graph1.component_instances["Imputer"].parameters[
+            "numeric_impute_strategy"
+        ]
+        == "mean"
+    )
+
+    # make sure the value gets overwritten when reinitialized
+    bcp = BinaryClassificationPipeline(
+        component_graph1, parameters={"Imputer": {"numeric_impute_strategy": "median"}}
+    )
+    assert bcp.parameters["Imputer"]["numeric_impute_strategy"] == "median"
+    assert (
+        bcp.component_graph.component_instances["Imputer"].parameters[
+            "numeric_impute_strategy"
+        ]
+        == "median"
+    )
