@@ -191,12 +191,15 @@ _not_used_in_automl = {
     "BaselineClassifier",
     "BaselineRegressor",
     "TimeSeriesBaselineEstimator",
-    "SklearnStackedEnsembleClassifier",
-    "SklearnStackedEnsembleRegressor",
+    "StackedEnsembleClassifier",
+    "StackedEnsembleRegressor",
     "KNeighborsClassifier",
     "SVMClassifier",
     "SVMRegressor",
     "LinearRegressor",
+    "VowpalWabbitBinaryClassifier",
+    "VowpalWabbitMulticlassClassifier",
+    "VowpalWabbitRegressor",
 }
 
 
